/*   
     system:        CalSAWS Conversion
     procedure:     CalSAWSAidCodeMap.tab
     written by:    Craig Deane
     date written:  9/10/2020
     database:      welcoll
     function:      Creates the CalSAWSAidCodeMap table used to map VACS Aid codes to CalSAWS Aid Codes
     modified by:   
     changes:       
 */

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSAidCodeMap') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSAidCodeMap
              END
Go

CREATE TABLE dbo.CalSAWSAidCodeMap
       (vacs_code	char(3),
	vacs_description	varchar(255),
	calsaws_description	varchar(255),
	calsaws_code	char(2),
	Primary Key(vacs_code)
 )
go

grant select, insert, update, delete on CalSAWSAidCodeMap to public
go


insert CalSAWSAidCodeMap
values('00 ', 'GCC', '', '  ')
insert CalSAWSAidCodeMap
values('01 ', 'FOO', '', '  ')
insert CalSAWSAidCodeMap
values('03 ', 'AAP', 'Adoption Assistance - Federal', '03')
insert CalSAWSAidCodeMap
values('04 ', 'AAP', 'Adoption Assistance - State Only', '04')
insert CalSAWSAidCodeMap
values('05 ', 'FOS', 'Seriously Emotionally Disturbed - Non Emergency As', '05')
insert CalSAWSAidCodeMap
values('09 ', 'FOO', 'Non Assistance CalFresh', '09')
insert CalSAWSAidCodeMap
values('0F ', 'FOO', 'Transitional CalFresh', '0F')
insert CalSAWSAidCodeMap
values('1A ', 'CAP', '0D - MCAP Pregnant Woman-213-322% FPL', '0D')
insert CalSAWSAidCodeMap
values('2L ', 'IHS', 'IHSS Plus Waiver', '2L')
insert CalSAWSAidCodeMap
values('2M ', 'IHS', 'Personal Care Services', '2M')
insert CalSAWSAidCodeMap
values('2N ', 'IHS', 'IHSS Residual', '2N')
insert CalSAWSAidCodeMap
values('30 ', 'AFF', 'CalWORKs -TANF Timed Out - All Families (Fed)', '30')
insert CalSAWSAidCodeMap
values('32 ', 'AFF', 'CalWORKs -TANF Timed Out -All Families (State)', '32')
insert CalSAWSAidCodeMap
values('33 ', 'AFF', 'CalWORKs -Zero Parent (Federal)', '33')
insert CalSAWSAidCodeMap
values('35 ', 'AFF', 'CalWORKs -Two Parent (Federal)', '35')
insert CalSAWSAidCodeMap
values('3A ', 'AFF', 'CalWORKs - Timed Out Safety Net  All Families (Prior to 12/2013)', '3A')
insert CalSAWSAidCodeMap
values('3C ', 'AFU', 'CalWORKs - Timed Out - Safety Net Two Parent (Prior to 12/2013)', '3C')
insert CalSAWSAidCodeMap
values('3E ', 'AFF', 'CalWORKs -All Families (Mixed)', '3E')
insert CalSAWSAidCodeMap
values('3F ', 'AFF', 'CalWORKs - Safety Net/Fleeing Felon/Long-Term WTW Sanction - Two Parent', '3F')
insert CalSAWSAidCodeMap
values('3G ', 'AFF', 'CalWORKs -Zero Parent (State Only)', '3G')
insert CalSAWSAidCodeMap
values('3L ', 'AFF', 'CalWORKs All Families (State Only)', '3L')
insert CalSAWSAidCodeMap
values('3M ', 'AFU', 'CalWORKs -Two Parent - State Only', '3M')
insert CalSAWSAidCodeMap
values('3P ', 'AFF', 'CalWORKs -All Families- Exempt MAP (Federal)', '3P')
insert CalSAWSAidCodeMap
values('3R ', 'AFF', 'CalWORKs -Zero Parent - Exempt MAP (Federal)', '3R')
insert CalSAWSAidCodeMap
values('3U ', 'AFU', 'CalWORKs -Two Parent (State)', '3U')
insert CalSAWSAidCodeMap
values('3W ', 'AFF', 'CalWORKs - TANF - Timed Out (State)', '3W')
insert CalSAWSAidCodeMap
values('40 ', 'FOS', 'AFDC-Foster Care (State Only)', '40')
insert CalSAWSAidCodeMap
values('42 ', 'FOS', 'AFDC-Foster Care (Federal)', '42')
insert CalSAWSAidCodeMap
values('43 ', 'FOS', '43 - FC Extended (State) beyond age 18', '43')
insert CalSAWSAidCodeMap
values('49 ', 'FOS', '49 - FC Extended (Federal) beyond age 18', '49')
insert CalSAWSAidCodeMap
values('4C ', 'FOS', 'Voluntary Placement', '4C')
insert CalSAWSAidCodeMap
values('4F ', 'FOS', 'Kin-GAP (State Only)', '4F')
insert CalSAWSAidCodeMap
values('4K ', 'FOS', 'Probation Emergency Assistance', '4K')
insert CalSAWSAidCodeMap
values('4S ', 'FOS', 'Kin-GAP Extended (Federal)', '4S')
insert CalSAWSAidCodeMap
values('4T ', 'FOS', 'Kin-GAP (Federal)', '4T')
insert CalSAWSAidCodeMap
values('5K ', 'FOS', 'Emergency Assistance - Foster Care', '5K')
insert CalSAWSAidCodeMap
values('6K ', 'CAP', 'CAPI - Non Qualified', '6K')
insert CalSAWSAidCodeMap
values('6M ', 'CAP', 'CAPI - Sponsored', '6M')
insert CalSAWSAidCodeMap
values('6T ', 'CAP', 'CAPI-LimitedTerm', '6T')
insert CalSAWSAidCodeMap
values('90 ', 'GEN', '90 - General Assistance', '90')
insert CalSAWSAidCodeMap
values('91 ', 'GEN', '91 – GA/GR Employable, Independent Living, Single', '91')
insert CalSAWSAidCodeMap
values('92 ', 'GEN', '92 – GA/GR Employable, Facility, Family Group', '92')
insert CalSAWSAidCodeMap
values('93 ', 'GEN', '93 – GA/GR Employable, Facility, Single', '93')
insert CalSAWSAidCodeMap
values('94 ', 'GEN', '94 – GA/GR Unemployable, Independent Living, Family Group', '94')
insert CalSAWSAidCodeMap
values('95 ', 'GEN', '95 – GA/GR Unemployable, Independent Living, Single', '95')
insert CalSAWSAidCodeMap
values('96 ', 'GEN', '96 – GA/GR Unemployable, Facility, Family Group', '96')
insert CalSAWSAidCodeMap
values('97 ', 'GEN', '97 – GA/GR Unemployable, Facility, Single', '97')
insert CalSAWSAidCodeMap
values('9K ', 'FOS', '', '  ')
insert CalSAWSAidCodeMap
values('9X ', 'FOS', '', '  ')
insert CalSAWSAidCodeMap
values('A4 ', 'AFF', '', '  ')
insert CalSAWSAidCodeMap
values('B5 ', 'GEN', '', '  ')
insert CalSAWSAidCodeMap
values('K1 ', 'AFF', 'CalWORKs - Safety Net/Fleeing Felon/Long-Term WTW Sanction - Non-Two Parent', 'K1')
insert CalSAWSAidCodeMap
values('OF ', 'FOO', '', '  ')
insert CalSAWSAidCodeMap
values('R4 ', 'FOO', 'R4 - Work Incentive Nutrisional Supplement', 'R4')
insert CalSAWSAidCodeMap
values('R5 ', 'FOO', 'R5 - Work Incentive Nutrisional Supplement', 'R5')
insert CalSAWSAidCodeMap
values('R6 ', 'FOO', 'R6 - Work Incentive Nutrisional Supplement', 'R6')
insert CalSAWSAidCodeMap
values('R7 ', 'FOO', 'R7 - Work Incentive Nutrisional Supplement', 'R7')
insert CalSAWSAidCodeMap
values('R8 ', 'FOO', 'R8 - Work Incentive Nutrisional Supplement', 'R8')
insert CalSAWSAidCodeMap
values('R9 ', 'FOO', 'R9 - Work Incentive Nutrisional Supplement', 'R9')
insert CalSAWSAidCodeMap
values('WW ', 'WTW', '', '  ')







/*   
     system:        CalSAWS Conversion
     procedure:     CalSAWSLanguageCodeMap.tab
     written by:    Craig Deane
     date written:  12/3/2020
     database:      welcoll
     function:      Creates the CalSAWSLanguageCodeMap table used to map VACS Language codes to CalSAWS Language Codes
     modified by:   
     changes:       
 */

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSLanguageCodeMap') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSLanguageCodeMap
              END
Go

CREATE TABLE dbo.CalSAWSLanguageCodeMap
       (vacs_code	char(3),
	vacs_description	varchar(255),
	calsaws_description	varchar(255),
	calsaws_code	char(2),
	Primary Key(vacs_code)
 )
go

grant select, insert, update, delete on CalSAWSLanguageCodeMap to public
go

insert CalSAWSLanguageCodeMap
values('0', 'American Sign Language', 'American Sign Language', '01')
insert CalSAWSLanguageCodeMap
values('1', 'Spanish', 'Spanish', '02')
insert CalSAWSLanguageCodeMap
values('2', 'Cantonese', 'Cantonese (Chinese)', '10')
insert CalSAWSLanguageCodeMap
values('3', 'Japanese', 'Japanese', '04')
insert CalSAWSLanguageCodeMap
values('4', 'Korean', 'Korean', '05')
insert CalSAWSLanguageCodeMap
values('5', 'Tagalog', 'Tagalog, Filipino', '06')
insert CalSAWSLanguageCodeMap
values('6', 'Other Non-English', 'Other Non-English', '07')
insert CalSAWSLanguageCodeMap
values('7', 'English', 'English', '03')
insert CalSAWSLanguageCodeMap
values('A', 'Other Sign Language', 'Other Sign Language', '09')
insert CalSAWSLanguageCodeMap
values('B', 'Mandarin', 'Mandarin (Chinese)', '11')
insert CalSAWSLanguageCodeMap
values('C', 'Other Chinese Language', 'Other Chinese Language', '08')
insert CalSAWSLanguageCodeMap
values('D', 'Cambodian', 'Cambodian', '12')
insert CalSAWSLanguageCodeMap
values('E', 'Armenian', 'Armenian', '13')
insert CalSAWSLanguageCodeMap
values('F', 'Ilacano', 'Ilocano', '14')
insert CalSAWSLanguageCodeMap
values('G', 'Mein', 'Mien', '15')
insert CalSAWSLanguageCodeMap
values('H', 'Hmong', 'Hmong', '16')
insert CalSAWSLanguageCodeMap
values('I', 'Lao', 'Lao', '17')
insert CalSAWSLanguageCodeMap
values('J', 'Turkish', 'Turkish', '18')
insert CalSAWSLanguageCodeMap
values('K', 'Hebrew', 'Hebrew', '19')
insert CalSAWSLanguageCodeMap
values('L', 'French', 'French', '20')
insert CalSAWSLanguageCodeMap
values('M', 'Polish', 'Polish', '21')
insert CalSAWSLanguageCodeMap
values('N', 'Russian', 'Russian', '22')
insert CalSAWSLanguageCodeMap
values('P', 'Portuguese', 'Portuguese', '23')
insert CalSAWSLanguageCodeMap
values('Q', 'Italian', 'Italian', '24')
insert CalSAWSLanguageCodeMap
values('R', 'Arabic', 'Arabic', '25')
insert CalSAWSLanguageCodeMap
values('S', 'Samoan', 'Samoan', '26')
insert CalSAWSLanguageCodeMap
values('T', 'Thai', 'Thai', '27')
insert CalSAWSLanguageCodeMap
values('U', 'Farsi', 'Farsi', '28')
insert CalSAWSLanguageCodeMap
values('V', 'Vietnamese', 'Vietnamese', '29')

go






/*   
     system:        CalSAWS Conversion
     procedure:     CalSAWSProgramCodeMap.tab
     written by:    Craig Deane
     date written:  9/2/2020
     database:      welcoll
     function:      Creates the CalSAWSProgramCodeMap table used to map VACS Case Type codes to CalSAWS Program Codes
     modified by:   Craig Deane 6/10/2021 FSD 1.7
     changes:       Added the exclude_indicator
 */

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSProgramCodeMap') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSProgramCodeMap
              END
Go

CREATE TABLE dbo.CalSAWSProgramCodeMap
       (vacs_code		char(3),
	vacs_description	varchar(255),
	calsaws_description	varchar(255),
	calsaws_code		char(2),
	exclude_indicator	char(1)
	Primary Key(vacs_code)
 )
go

grant select, insert, update, delete on CalSAWSProgramCodeMap to public
go

insert CalSAWSProgramCodeMap
values('AAP', 'ADOPTION ASSISTANCE PROGRAM', 'Adoptions Assistance Program', 'AA', 0)
insert CalSAWSProgramCodeMap
values('AFF', 'AFDC-FG', 'CalWORKs', 'CW', 0)
insert CalSAWSProgramCodeMap
values('AFU', 'AFDC-U', 'CalWORKs', 'CW', 0)
insert CalSAWSProgramCodeMap
values('CAP', 'CAPI', 'Cash Assistance Program for Immigrants', 'CP', 0)
insert CalSAWSProgramCodeMap
values('CFG', 'CALWORKs Pure State-Only', 'CalWORKs', 'CW', 0)
insert CalSAWSProgramCodeMap
values('DIS', 'AID TO DISABLED', '', '  ', 0)
insert CalSAWSProgramCodeMap
values('FOO', 'FOOD STAMPS', 'CalFresh', 'FS', 0)
insert CalSAWSProgramCodeMap
values('FOS', 'FOSTER CARE', 'Foster Care', 'FC', 0)
insert CalSAWSProgramCodeMap
values('GCC', 'GAIN-CHILD CARE', 'Child Care', 'CC', 0)
insert CalSAWSProgramCodeMap
values('GEN', 'GENERAL RELIEF', 'General Assistance/General Relief', 'GA', 0)
insert CalSAWSProgramCodeMap
values('GTB', 'GAIN-TOOLS, BOOKS, ETC', 'General Assistance/General Relief', 'GA', 0)
insert CalSAWSProgramCodeMap
values('GTR', 'GAIN-TRANSPORTATION', 'General Assistance/General Relief', 'GA', 0)
insert CalSAWSProgramCodeMap
values('GWT', 'GAIN-WORK/TRAINING', 'General Assistance/General Relief', 'GA', 0)
insert CalSAWSProgramCodeMap
values('HOM', 'HOMELESS', 'Homeless', 'HO', 0)
insert CalSAWSProgramCodeMap
values('IHS', 'IHSS', 'In Home Supportive Services (IHSS)', 'IH', 0)
insert CalSAWSProgramCodeMap
values('IRA', 'IRAP', '', '  ', 0)
insert CalSAWSProgramCodeMap
values('PRO', 'PROBATION', '', '  ', 0)
insert CalSAWSProgramCodeMap
values('RCA', 'Refugee Cash Assistance', 'Refugee Cash Assistance', 'RC', 0)
insert CalSAWSProgramCodeMap
values('SCC', 'SUPPLEMENTAL CHILD CARE', 'Child Care', 'CC', 0)
insert CalSAWSProgramCodeMap
values('SED', 'SED', '', '  ', 0)
insert CalSAWSProgramCodeMap
values('SNA', 'SAFETY NET - ALL', '', '  ', 0)
insert CalSAWSProgramCodeMap
values('TCC', 'TRANSITIONAL CHILD CARE', 'Child Care', 'CC', 0)




/*   
     system:        CalSAWS Conversion
     procedure:     CalSAWSRecoveryAccountCauseMap.tab
     written by:    Craig Deane
     date written:  9/3/2020
     database:      welcoll
     function:      Creates the CalSAWSRecoveryAccountCauseMap table used to map VACS Case Type/Debt Type combinations to the CalSAWS Recovery Account Cause codes
     modified by:   
     changes:       
 */

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSRecoveryAccountCauseMap') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSRecoveryAccountCauseMap
              END
Go

CREATE TABLE dbo.CalSAWSRecoveryAccountCauseMap
       (debt_type_code	char(3),
	type_code	char(3),
	description	varchar(255),
	calsaws_description	varchar(255),
	calsaws_code	char(2),
	Primary Key(debt_type_code, type_code)
 )
go

grant select, insert, update, delete on CalSAWSRecoveryAccountCauseMap to public
go

insert CalSAWSRecoveryAccountCauseMap
values('ADM', 'AFF', 'Administrative Error', ' Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCauseMap
values('ADM', 'AFU', 'Administrative Error', ' Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCauseMap
values('ADM', 'CAP', 'Administrative Error', ' Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCauseMap
values('ADM', 'FOO', 'ADMINISTRATIVE ERROR', ' CalFresh - Admin Caused (after 3/2000)', 'AQ')
insert CalSAWSRecoveryAccountCauseMap
values('ADM', 'HOM', 'Administrative Error', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('AF ', 'CAP', 'At Fault', ' CAPI Recoverable', 'CR')
insert CalSAWSRecoveryAccountCauseMap
values('AGE', 'AFF', 'AGENCY ERROR', ' Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCauseMap
values('AGE', 'AFU', 'AGENCY ERROR', ' Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCauseMap
values('AGE', 'FOS', 'AGENCY ERROR', ' Foster Care - Admin Caused - ET Responsible', 'BA')
insert CalSAWSRecoveryAccountCauseMap
values('AGE', 'SCC', 'Agency Error', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('IHE', 'AFF', 'Inadvertant Household Error', ' Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCauseMap
values('IHE', 'AFU', 'Inadvertant Household Error', ' CalFresh - IHE (Customer Caused)', 'AR')
insert CalSAWSRecoveryAccountCauseMap
values('IHE', 'CAP', 'INADVERTANT HOUSEHOLD ERROR', ' CAPI Recoverable', 'CR')
insert CalSAWSRecoveryAccountCauseMap
values('IHE', 'FOO', 'INADVERTANT HOUSEHOLD ERROR', ' CalFresh - IHE (Customer Caused)', 'AR')
insert CalSAWSRecoveryAccountCauseMap
values('IHE', 'HOM', 'Inadvertant Household Error', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('IPV', 'AFF', 'Intentional Program Violation', ' Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCauseMap
values('IPV', 'AFU', 'Intentional Program Violation', ' Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCauseMap
values('IPV', 'FOO', 'POTENTIAL IPV', ' CalFresh - Potential IPV', 'AS')
insert CalSAWSRecoveryAccountCauseMap
values('IPV', 'HOM', 'Intentional Program Violation', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('NON', 'DIS', 'None', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('NON', 'GCC', 'None', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('NON', 'GEN', 'None', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('NON', 'GTB', 'None', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('NON', 'GTR', 'None', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('NON', 'GWT', 'None', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('NON', 'HOM', 'None', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('NON', 'IRA', 'None', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('NON', 'SCC', 'None', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('NON', 'SED', 'None', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('NON', 'SNA', 'None', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('NON', 'TCC', 'None', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('OTH', 'AAP', 'OTHER', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('OTH', 'AFF', 'OTHER', ' Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCauseMap
values('OTH', 'AFU', 'OTHER', ' Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCauseMap
values('OTH', 'CAP', 'OTHER', ' CAPI Recoverable', 'CR')
insert CalSAWSRecoveryAccountCauseMap
values('OTH', 'FOS', 'OTHER', ' Foster Care - Admin Caused - ET Responsible', 'BA')
insert CalSAWSRecoveryAccountCauseMap
values('OTH', 'GCC', 'OTHER', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('OTH', 'GTB', 'OTHER', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('OTH', 'GTR', 'OTHER', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('OTH', 'GWT', 'OTHER', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('OTH', 'IHS', 'IHSS', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('OTH', 'PRO', 'OTHER', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('OTH', 'RCA', 'Other', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('OTH', 'SCC', 'OTHER', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('OTH', 'SNA', 'OTHER', '', '  ')
insert CalSAWSRecoveryAccountCauseMap
values('TOP', 'AFF', 'TECHNICAL OVERPAYMENT', ' Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCauseMap
values('TOP', 'AFU', 'TECHNICAL OVERPAYMENT', ' Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCauseMap
values('TOP', 'FOS', 'TECHNICAL OVERPAYMENT', ' Foster Care - Admin Caused - ET Responsible', 'BA')






/*   
     system:        CalSAWS Conversion
     procedure:     CalSAWSRecoveryAccountReasonMap.tab
     written by:    Craig Deane
     date written:  9/3/2020
     database:      welcoll
     function:      Creates the CalSAWSRecoveryAccountReasonMap table used to map VACS Debt Reason codes to CalSAWS Reason Codes
     modified by:   
     changes:       
 */

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSRecoveryAccountReasonMap') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSRecoveryAccountReasonMap
              END
Go

CREATE TABLE dbo.CalSAWSRecoveryAccountReasonMap
       (vacs_code	char(3),
	vacs_description	varchar(255),
	calsaws_description	varchar(255),
	calsaws_code	char(2),
	Primary Key(vacs_code)
 )
go

grant select, insert, update, delete on CalSAWSRecoveryAccountReasonMap to public
go

insert CalSAWSRecoveryAccountReasonMap
values('AAP', 'ADOPTION ASSISTANCE PROGRAM', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('AFF', 'AFDC-FG', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('AFU', 'AFDC-U', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('BUD', 'BUDGET COMPUTATION ERROR', 'Administrative Error', 'AE')
insert CalSAWSRecoveryAccountReasonMap
values('CAL', 'LATE CA-7, NOT ELIGIBLE FOR DISREGARDS', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('CAN', 'CA-7 NOT PROCESSED TIMELY', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('CAP', 'CAPI', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('CFG', 'CALWORKs Pure State-Only', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('CHA', 'CHANGE REPORTED - NOT PROCESSED TIMELY', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('COM', 'COMPUTATIONAL ERROR', 'Administrative Error', 'AE')
insert CalSAWSRecoveryAccountReasonMap
values('DED', 'DEDUCTION ALLOWED BE NOT VERIFIED', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('DIS', 'AID TO DISABLED', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('ERR', 'COMPUTER DOCUMENT ENTRY ERROR', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('FOO', 'FOOD STAMPS', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('FOS', 'FOSTER CARE', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('FRI', 'FAILURE TO REPORT & VERIFY INCOME', 'Failure to Provide Essential Information', 'FP')
insert CalSAWSRecoveryAccountReasonMap
values('FRM', 'FAILURE TO REPORT AU MEMBER LEAVING', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('FTE', 'FULL TIME EMPLOYMENT OF U-PARENT', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('GCC', 'GAIN-CHILD CARE', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('GEN', 'KINGAP OVERPAYMENT', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('GTB', 'GAIN-TOOLS, BOOKS, ETC', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('GTR', 'GAIN-TRANSPORTATION', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('GWT', 'GAIN-WORK/TRAINING', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('HFR', 'HOUSEHOLD FAILED TO REPORT TIMELY', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('HOM', 'HOMELESS', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('HSI', 'HOUSEHOLD SIZE REPORTED INCORRECTLY', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('IEM', 'INCOME EXCEEDS MAXIMUM LIMITS', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('IHS', 'IHSS', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('INC', 'INCOME INCREASED, NO TIME TO ISSUE NOA', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('INE', 'INELIGIBLE INDIVIDUAL NOT DISCONTINUED', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('IRA', 'IRAP', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('NED', 'NEEDS DECREASED, NO TIME TO ISSUE NOA', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('NON', 'None', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('OTH', 'OTHER', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('PEN', 'AID PAID PENDING STATE HEARING', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('PRO', 'PROPERTY EXCEEDS MAXIMUM LIMITS', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('RCA', 'Refugee Cash Assistance', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('REC', 'RECONCILIATION OF INTAKE''S PROJECTION', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('SCC', 'SUPPLEMENTAL CHILD CARE', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('SED', 'SED', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('SNA', 'SAFETY NET - ALL', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('TCC', 'TRANSITIONAL CHILD CARE', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('UEI', 'UNREPORTED EARNED INCOME', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('URP', 'UNREPORTED RESOURCES/PROPERTY', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('UUI', 'UNREPORTED UNEARNED INCOME', '', '  ')
insert CalSAWSRecoveryAccountReasonMap
values('VOL', 'VOLUNTARY REPAYMENT', '', '  ')




/*   
	system:		CalSAWS Conversion
     	procedure:     	CalSAWSRecoveryAccountStatusMap.tab
     	written by:    	Craig Deane
     	date written:  	10/12/2020
     	database:      	welcoll
     	function:      	Creates the CalSAWSRecoveryAccountStatusMap table used to map VACS Debt Status to the CalSAWS Recovery Account Status codes
     	modified by:   	Craig Deane 6/10/2021 FSD 1.7
     	changes:       	Added the exclude_zero_balance_indicator column 
*/

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSRecoveryAccountStatusMap') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSRecoveryAccountStatusMap
              END
Go

CREATE TABLE dbo.CalSAWSRecoveryAccountStatusMap
       (vacs_code	char(1),
	vacs_description	varchar(255),
	calsaws_description	varchar(255),
	calsaws_code	char(2),
	exclude_zero_balance_indicator	char(1) default 0
	Primary Key(vacs_code)
 )
go

grant select, insert, update, delete on CalSAWSRecoveryAccountStatusMap to public
go

insert CalSAWSRecoveryAccountStatusMap
values('A', 'Cancel', 'Voided', 'VO', 0)
insert CalSAWSRecoveryAccountStatusMap
values('B', 'Bankruptcy', 'Suspended', 'SU', 0)
insert CalSAWSRecoveryAccountStatusMap
values('C', 'Closed', 'Closed', 'CL', 0)
insert CalSAWSRecoveryAccountStatusMap
values('D', 'Deceased', 'Terminated', 'TE', 0)
insert CalSAWSRecoveryAccountStatusMap
values('H', 'Hearing', 'Suspended', 'SU', 0)
insert CalSAWSRecoveryAccountStatusMap
values('L', 'Lomeli Write Off', 'Terminated', 'TE', 0)
insert CalSAWSRecoveryAccountStatusMap
values('O', 'Open', 'Active', 'AC', 0)
insert CalSAWSRecoveryAccountStatusMap
values('P', 'Pending', 'Pending', 'PE', 0)
insert CalSAWSRecoveryAccountStatusMap
values('S', 'Suspend', 'Suspended', 'SU', 0)
insert CalSAWSRecoveryAccountStatusMap
values('V', 'Void', 'Voided', 'VO', 0)
insert CalSAWSRecoveryAccountStatusMap
values('W', 'Write Off', 'Terminated', 'TE', 0)

go





/*   
     system:        CalSAWS Conversion
     procedure:     CalSAWSRecoveryAccountStatusReasonMap.tab
     written by:    Craig Deane
     date written:  4/29/2021
     database:      welcoll
     function:      Creates the CalSAWSRecoveryAccountStatusReasonMap table used to map VACS Debt Status to the CalSAWS Recovery Account Status Reason codes
     modified by:   
     changes:       
 */

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSRecoveryAccountStatusReasonMap') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSRecoveryAccountStatusReasonMap
              END
Go

CREATE TABLE dbo.CalSAWSRecoveryAccountStatusReasonMap
       (vacs_code	char(1),
	vacs_description	varchar(255),
	calsaws_description	varchar(255),
	calsaws_code	char(2),
	Primary Key(vacs_code)
 )
go

grant select, insert, update, delete on CalSAWSRecoveryAccountStatusReasonMap to public
go

insert CalSAWSRecoveryAccountStatusReasonMap
values('A', 'Cancel', 'Admin Decision', 'AD')
insert CalSAWSRecoveryAccountStatusReasonMap
values('B', 'Bankruptcy', 'Bankruptcy', 'BR')
insert CalSAWSRecoveryAccountStatusReasonMap
values('C', 'Closed', 'Paid in Full', 'PF')
insert CalSAWSRecoveryAccountStatusReasonMap
values('D', 'Deceased', 'Deceased', 'DE')
insert CalSAWSRecoveryAccountStatusReasonMap
values('H', 'Hearing', 'Admin Hearing', 'AH')
insert CalSAWSRecoveryAccountStatusReasonMap
values('L', 'Lomeli Write Off', 'Compromised (Lomeli)', 'CL')
insert CalSAWSRecoveryAccountStatusReasonMap
values('O', 'Open', 'Active', 'AC')
insert CalSAWSRecoveryAccountStatusReasonMap
values('P', 'Pending', 'In-Process', 'IP')
insert CalSAWSRecoveryAccountStatusReasonMap
values('S', 'Suspend', 'Admin Decision', 'AD')
insert CalSAWSRecoveryAccountStatusReasonMap
values('V', 'Void', 'Admin Decision', 'AD')
insert CalSAWSRecoveryAccountStatusReasonMap
values('W', 'Write Off', 'Write-Off', 'WO')

go





/*   
     system:        CalSAWS Conversion
     procedure:     CalSAWSTransactionTypeMap.tab
     written by:    Craig Deane
     date written:  10/14/2020
     database:      welcoll
     function:      Creates the CalSAWSTransactionCodeMap table used to map VACS Transaction Types to CalSAWS Transaction Types
     modified by:   
     changes:       
 */

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSTransactionTypeMap') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSTransactionTypeMap
              END
Go

CREATE TABLE dbo.CalSAWSTransactionTypeMap
       (vacs_code	char(3),
	vacs_description	varchar(255),
	calsaws_description	varchar(255),
	calsaws_code	char(2),
	Primary Key(vacs_code)
 )
go

grant select, insert, update, delete on CalSAWSTransactionTypeMap to public
go

insert CalSAWSTransactionTypeMap
values('BEN', 'Benefit Reduction', 'Benefit Reduction', 'BR')
insert CalSAWSTransactionTypeMap
values('CMP', 'Compromise', 'Compromised', 'CO')
insert CalSAWSTransactionTypeMap
values('COR', 'Correction', 'Back Out', 'BO')
insert CalSAWSTransactionTypeMap
values('DFS', 'Dormant Food Stamps', 'Expungement', 'EX')
insert CalSAWSTransactionTypeMap
values('EBC', 'EBT - Cash Payment', 'EBT - Cash', 'EC')
insert CalSAWSTransactionTypeMap
values('EBF', 'EBT - Food Stamp Payment', 'EBT - CalFresh', 'EF')
insert CalSAWSTransactionTypeMap
values('EXP', 'Expunge', 'Expungement', 'EX')
insert CalSAWSTransactionTypeMap
values('FTB', 'FTB Intercept Payment', 'Tax Intercept - FTB (65%)', 'FT')
insert CalSAWSTransactionTypeMap
values('GRA', 'Grant Adjustment', 'Benefit Reduction', 'BR')
insert CalSAWSTransactionTypeMap
values('INT', 'Interest', '', '  ')
insert CalSAWSTransactionTypeMap
values('IRS', 'IRS Intercept Payment', 'Offset Payment', 'OP')
insert CalSAWSTransactionTypeMap
values('IRV', 'IRS Reversal', '', '  ')
insert CalSAWSTransactionTypeMap
values('ITC', 'Intercept Payment', 'Offset Payment ', 'OP')
insert CalSAWSTransactionTypeMap
values('LOM', 'Lomeli Write Off', 'Written Off', 'WO')
insert CalSAWSTransactionTypeMap
values('MSP', 'Miscellaneous Payment', '', '  ')
insert CalSAWSTransactionTypeMap
values('NCR', 'Refund - Non-Cash', 'Reimbursement of Aid', 'RI')
insert CalSAWSTransactionTypeMap
values('OFF', 'Offset', 'Offset', 'OF')
insert CalSAWSTransactionTypeMap
values('OTH', 'Other Adjustment', 'Overpayment Adjustment Transaction', 'OV')
insert CalSAWSTransactionTypeMap
values('OVP', 'Overpayment', '', '  ')
insert CalSAWSTransactionTypeMap
values('PFS', 'Payment (Food Stamp)', 'EBT - CalFresh', 'EF')
insert CalSAWSTransactionTypeMap
values('PMT', 'Payment', 'Payment Reduction', 'PR')
insert CalSAWSTransactionTypeMap
values('REF', 'Refund - Cash', 'Refund', 'RF')
insert CalSAWSTransactionTypeMap
values('REV', 'Revision', 'Back Out', 'BO')
insert CalSAWSTransactionTypeMap
values('RVR', 'Reversal', 'Overpayment Adjustment Transaction', 'OV')
insert CalSAWSTransactionTypeMap
values('TRC', 'Transfer Credit', 'Transfer', 'TN')
insert CalSAWSTransactionTypeMap
values('VOI', 'Void', 'Void', 'VO')
insert CalSAWSTransactionTypeMap
values('WAV', 'Overpayment Waived', '', '  ')
insert CalSAWSTransactionTypeMap
values('WRI', 'Write Off', 'Written Off', 'WO')






/*   
     system:        CalSAWS Conversion
     procedure:     Line2Address.tab
     written by:    Craig Deane
     date written:  01/13/2021
     database:      welcoll
     function:      Creates the Line2Address table
     modified by:   
     changes:       
   
 */

use welcoll
go
 

IF OBJECT_ID('dbo.Line2Address') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.Line2Address
              END
Go

CREATE TABLE dbo.Line2Address
(
	key_number	INT IDENTITY(1,1) PRIMARY KEY,
	unit		varchar(50)
)
go

grant select, insert, update, delete on Line2Address to public
go


insert Line2Address
values('#')
insert Line2Address
values('APT')
insert Line2Address
values('BAY')
insert Line2Address
values('BLDG')
insert Line2Address
values('BSMT')
insert Line2Address
values('FL')
insert Line2Address
values('FRNT')
insert Line2Address
values('LOT')
insert Line2Address
values('LOWR')
insert Line2Address
values('OFC')
insert Line2Address
values('PIER')
insert Line2Address
values('PMB')
insert Line2Address
values('REAR')
insert Line2Address
values('RM')
insert Line2Address
values('SIDE')
insert Line2Address
values('SLIP')
insert Line2Address
values('SPC')
insert Line2Address
values('STE')
insert Line2Address
values('TRLR')
insert Line2Address
values('UNIT')
insert Line2Address
values('UPPR')
go



/*   
     system:        CalSAWS Conversion
     procedure:     NameSuffix.tab
     written by:    Craig Deane
     date written:  10/16/2020
     database:      welcoll
     function:      Creates the NameSuffix table
     modified by:   
     changes:       
   
 */

use welcoll
go
 

IF OBJECT_ID('dbo.NameSuffix') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.NameSuffix
              END
Go

CREATE TABLE dbo.NameSuffix
(
	key_number	INT IDENTITY(1,1) PRIMARY KEY,
	suffix		varchar(5)
)
go

grant select, insert, update, delete on NameSuffix to public
go

insert NameSuffix
values('1')
insert NameSuffix
values('2')
insert NameSuffix
values('3')
insert NameSuffix
values('4')
insert NameSuffix
values('5')
insert NameSuffix
values('6')
insert NameSuffix
values('7')
insert NameSuffix
values('I')
insert NameSuffix
values('II')
insert NameSuffix
values('III')
insert NameSuffix
values('IV')
insert NameSuffix
values('JR')
insert NameSuffix
values('SR')
go





