/*   
	system:		CalSAWS Conversion
     	procedure:     	RecoveryAccount.tab
     	written by:    	Craig Deane
     	date written:  	7/30/2020
     	database:      	welcoll
     	function:      	creates the RecoveryAccount table
     	modified by:   	Craig Deane 10/6/2020
     	changes:       	Updated to reflect new layout 1.2
     	modified by:   	Craig Deane 10/7/2020
     	changes:       	Increased LegacyAccountNumberIdentifier to 11 chars
	modified by:   	Craig Deane 2/12/2020
     	changes:	Increased Staff ID to 15 characters. FSD 1.5
     	modified by:   	Craig Deane 3/10//2021 FSD 1.6
     	changes:       	Added the CDSCaseIndicator column
     	modified by:   	Craig Deane 3/25//2021 FSD 1.7
     	changes:       	Renamed CDSCaseIndicator to NonCalWINCaseIndicator
     	modified by:   	Craig Deane 4/5/2022 Version 2.2
     	changes:	Added the NotificationDate column	
 */

use welcoll
go
 

IF OBJECT_ID('dbo.RecoveryAccount') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.RecoveryAccount
              END
Go


CREATE TABLE dbo.RecoveryAccount
       (
	LegacyAccountNumberIdentifier	varchar(11),
	CaseNumber			char(7),
	OrganizationName		varchar(40), 	
	OrganizationID			char(9),
	PriorityNumber			int,
	ProgramCode			char(2),
	TypeCode			char(2), 
	ExpireDate			datetime,
	DiscoveryDate			datetime,
	StaffID				char(15),
	StatusCode			char(2),
	StatusReasonCode		char(2),
	ReasonCode			char(2),
	StatusDate			datetime,
	InvestigationCode		char(2),
	CurrentBalance			money,
	CauseCode			char(2),
	CauseDate			datetime,
	FinalDemandNoticeDate 		datetime,
	NonCalWINCaseIndicator		char(1),
	NotificationDate		datetime
 )
go

grant select, insert, update, delete on RecoveryAccount to public
go



/*   
	system:		CalSAWS Conversion
     	procedure:     	RecoveryAccountResponsibleParty.tab
     	written by:    	Craig Deane
     	date written:  	7/30/2020
     	database:      	welcoll
     	function:      	creates the RecoveryAccountResponsibleParty table
     	modified by:   	Craig Deane 12/3/2020 FSD 1.4
     	changes:       	Added PhysicalAddressEffectiveDate, MailingAddressEffectiveDate, Language, WrittenLanguage, and PersonNumberIdentifier
    	modified by:   	Craig Deane 9/30/2021 Version 2.0
     	changes:	Added CIN
   	modified by:   	Craig Deane 3/2/2023 Version 2.5
     	changes:	Added RecordType
 */

use welcoll
go
 

IF OBJECT_ID('dbo.RecoveryAccountResponsibleParty') IS NOT NULL
              BEGIN
                     DROP TABLE dbo.RecoveryAccountResponsibleParty
              END
Go

CREATE TABLE dbo.RecoveryAccountResponsibleParty
       (LegacyAccountNumberIdentifier	char(11),
	CaseNumber			char(7),
	PersonIdentifier		char(9),
	OrganizationID			char(9),
	AdjustmentIndicator		char(1),
	BillIndicator			char(1),
	TaxInterceptIndicator		char(1),
	ResponsiblePartyStatusDate	datetime,
	DelinquentDate			datetime,
	DebtorType			char(1),
	ResponsiblePartyFirstName	varchar(25),
	ResponsiblePartyMiddleName	char(1),
	ResponsiblePartyLastName	varchar(25),
	ResponsiblePartySuffix		char(5),
	ResponsiblePartyStatus		char(2),
	OrganizationName		varchar(60),
	AKAFirstName			varchar(30),
	AKAMiddleName			varchar(30),
	AKALastName			varchar(30),		
	AKASuffix			char(5),
	CoresponsibleFlag		char(1),
	PhysicalAddressEffectiveDate	datetime,
	PhysicalAddressLine1Address	varchar(50),
	PhysicalAddressLine2Address	varchar(50),
	PhysicalAddressCityName		varchar(50),	
	PhysicalAddressStateCode	char(2),
	PhysicalAddressZipCode		char(10),
	MailingAddressEffectiveDate	datetime,
	MailingAddressLine1Address	varchar(50),
	MailingAddressLine2Address	varchar(50),
	MailingAddressCityName		varchar(50),
	MailingAddressStateCode		char(2),
	MailingAddressZipCode		char(10),
	PhoneNumberAreaCode		char(3),
	PhoneNumber			char(7),
	PhoneExtensionNumber		char(4),
	ResponsiblePartyDateOfBirth	datetime,
	ResponsiblePartySSN		char(9),
	ResponsiblePartyDriverLicenseNumber	char(15),
	Language			char(2),
	WrittenLanguage			char(2),
	PersonNumberIdentifier		char(2),
	CIN				char(9),
	RecordType			char(1)
 )
go

grant select, insert, update, delete on RecoveryAccountResponsibleParty to public
go






/*   
     	system:        	CalSAWS Conversion
     	procedure:     	RecoveryAccountRepaymentTerm.tab
     	written by:    	Craig Deane
     	date written:  	7/30/2020
     	database:      	welcoll
     	function:      	creates the RecoveryAccountRepaymentTerm table
     	modified by:   	Craig Deane 10/12/2020
     	changes:       	Updated for new file layout
     	modified by:   	Craig Deane 4/5/2022 Version 2.2
     	changes:	Added the RepaymentTermStatus and RepaymentTermIncompleteReason columns
 */

use welcoll
go
 

IF OBJECT_ID('dbo.RecoveryAccountRepaymentTerm') IS NOT NULL
              BEGIN
                     DROP TABLE dbo.RecoveryAccountRepaymentTerm
              END
Go

CREATE TABLE dbo.RecoveryAccountRepaymentTerm
       (LegacyAccountNumberIdentifier	char(11),
	CaseNumber			char(7),
	PersonIdentifier		char(9),
	OrganizationID			char(9),
	OverrideCauseIndicator		char(1),
	RepayPercent			char(3),
	RepayAmount			money,
	FrequencyCode			char(2),
	BeginDate			datetime,
	TypeCode			char(2),
	EndDate				datetime,
	AgreementType			char(3),
	EntitlementType			char(3),
	RepaymentTermStatus		char(2),
	RepaymentTermIncompleteReason	char(2)
 )
go

grant select, insert, update, delete on RecoveryAccountRepaymentTerm to public
go







/*   
     system:        CalSAWS Conversion
     procedure:     RecoveryAccountOverpayment.tab
     written by:    Craig Deane
     date written:  7/30/2020
     database:      welcoll
     function:      Creates the RecoveryAccountOverpayment table
     modified by:   Craig Deane 10/12/2020
     changes:       Minor column name change for new file layout
 */

use welcoll
go
 

IF OBJECT_ID('dbo.RecoveryAccountOverpayment') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.RecoveryAccountOverpayment
              END
Go

CREATE TABLE dbo.RecoveryAccountOverpayment
       (LegacyAccountNumberIdentifier	char(11),
	OverpaymentAmount		money,
	EffectiveDate			datetime,
	OriginalAmount			money,
	CorrectedAmount			money,
	AidCode				char(2)
 )
go

grant select, insert, update, delete on RecoveryAccountOverpayment to public
go











/*   
     system:        CalSAWS Conversion
     procedure:     RecoveryAccountTransaction.tab
     written by:    Craig Deane
     date written:  10/12/2020
     database:      welcoll
     function:      Creates the RecoveryAccountTransaction table
     modified by:   
     changes:       
*/

use welcoll
go
 

IF OBJECT_ID('dbo.RecoveryAccountTransaction') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.RecoveryAccountTransaction
              END
Go

CREATE TABLE dbo.RecoveryAccountTransaction
       (
	LegacyAccountNumberIdentifier	varchar(11),
	TransactionNumberIdentifier	varchar(10),
	TransactionAmount		money,
	TransactionTypeCode		char(3),
	TransactionDeliveryTypeCode	char(3),
	EffectiveDate			datetime,
	PostedDate			datetime,
	BackedOutIndicator		char(1),
	PostedStatusCode		char(3)
 )
go
 
grant select, insert, update, delete on RecoveryAccountTransaction to public
go






/*   
     system:        CalSAWS Conversion
     procedure:     RecoveryAccountTransactionDetail.tab
     written by:    Craig Deane
     date written:  10/13/2020
     database:      welcoll
     function:      Creates the RecoveryAccountTransactionDetail table
     modified by:   
     changes:       
*/

use welcoll
go
 

IF OBJECT_ID('dbo.RecoveryAccountTransactionDetail') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.RecoveryAccountTransactionDetail
              END
Go

CREATE TABLE dbo.RecoveryAccountTransactionDetail
       (
	LegacyAccountNumberIdentifier	varchar(11),
	TransactionNumberIdentifier	varchar(10),
	TransactionDescription		varchar(2000)		
 )
go

grant select, insert, update, delete on RecoveryAccountTransactionDetail to public
go








/*   
     system:        CalSAWS Conversion
     procedure:     RecoveryAccountCaseNotes.tab
     written by:    Craig Deane
     date written:  10/13/2020
     database:      welcoll
     function:      Creates the RecoveryAccountCaseNotes table
     modified by:   Craig Deane 11/17/2022 Version 2.3
     changes:       Changed the NoteDescription	datatype to nvarchar to attempt to fix the byte length issue with Case Notes
     modified by:   Craig Deane 4/26/2023 Version 2.6
     changes:       Changed the NoteDescription	datatype to back to varchar
*/

use welcoll
go
 

IF OBJECT_ID('dbo.RecoveryAccountCaseNotes') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.RecoveryAccountCaseNotes
              END
Go

CREATE TABLE dbo.RecoveryAccountCaseNotes
       (
	LegacyAccountNumberIdentifier	varchar(11),
	NoteDescription		varchar(2000),
	DateNoteEntered		datetime
 )
go

grant select, insert, update, delete on RecoveryAccountCaseNotes to public
go








/*   
     	system:        	CalSAWS Conversion
     	procedure:     	RecoveryAccountProviders.tab
     	written by:    	Craig Deane
     	date written:  	June 2021
     	database:      	welcoll
     	function:      	creates the RecoveryAccountProviders table
     	modified by:   
     	changes:       
 */

use welcoll
go
 

IF OBJECT_ID('dbo.RecoveryAccountProviders') IS NOT NULL
              BEGIN
                     DROP TABLE dbo.RecoveryAccountProviders
              END
Go

CREATE TABLE dbo.RecoveryAccountProviders
       (LegacyAccountNumberIdentifier	char(11),
	OrganizationID			char(9),
	OrganizationName		varchar(40),
	TaxTypeCode			char(2),
	TaxIDType 			char(2),
	TaxID				char(9),
	PhysicalAddressLine1Address	varchar(50),
	PhysicalAddressLine2Address	varchar(50),
	PhysicalAddressCityName		varchar(50),	
	PhysicalAddressStateCode	char(2),
	PhysicalAddressZipCode		char(10),
	MailingAddressLine1Address	varchar(50),
	MailingAddressLine2Address	varchar(50),
	MailingAddressCityName		varchar(50),
	MailingAddressStateCode		char(2),
	MailingAddressZipCode		char(10),
	PhoneNumberAreaCode		char(3),
	PhoneNumber			char(7),
	PhoneExtensionNumber		char(4)
 )
go

grant select, insert, update, delete on RecoveryAccountProviders to public
go






/*   
     system:        CalSAWS Conversion
     procedure:     CalSAWSAidCode.tab
     written by:    Craig Deane
     date written:  9/10/2020
     database:      welcoll
     function:      Creates the CalSAWSProgramCode table that holds all of the CalSAWS Aid Codes
     modified by:   
     changes:       
 */

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSAidCode') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSAidCode
              END
Go

CREATE TABLE dbo.CalSAWSAidCode
       (number	integer,
	description	varchar(255),
	calsaws_code	char(2),
	PRIMARY KEY (number)
 )
go

grant select, insert, update, delete on CalSAWSAidCode to public
go


insert CalSAWSAidCode
values(1  , '(Newly Eligible) Title XIX, Medi-Cal No Share of Cost (SOC) County Compassionate Release/Medical Probation Program Inmates Citizen/SIS.', 'K6')
insert CalSAWSAidCode
values(2  , '(Newly Eligible) Title XIX/Title XXI, Medi-Cal No SOC for County Compassionate Release/Medical Probation Program Inmates, Non-SIS.', 'K7')
insert CalSAWSAidCode
values(3  , '(Not Newly Eligible) Title XIX, Medi-Cal No SOC for County Compassionate Release/Medical Probation Program Inmates, Citizen/SIS. disabled/blind.', 'K8')
insert CalSAWSAidCode
values(4  , '(Not Newly Eligible) Title XIX/Title XXI, Medi-Cal No SOC for County Compassionate Release/Medical Probation Program Inmates, Non-SIS.', 'K9')
insert CalSAWSAidCode
values(5  , '0D - MCAP Pregnant Woman-213-322% FPL', '0D')
insert CalSAWSAidCode
values(6  , '0E - Pregnant Women 213 - 322%', '0E')
insert CalSAWSAidCode
values(7  , '0G - MCAP Pregnant Woman - 213 - 322% FPL', '0G')
insert CalSAWSAidCode
values(8  , '10 - Aid to the Aged - SSI/SSP', '10')
insert CalSAWSAidCode
values(9  , '100 % - Child - Full Scope.', '7A')
insert CalSAWSAidCode
values(10 , '100 % Child - OBRA - ESO', '7C')
insert CalSAWSAidCode
values(11 , '100% Child - Excess Property - ESO', '8T')
insert CalSAWSAidCode
values(12 , '100% Child - Excess Property - Full Scope', '8R')
insert CalSAWSAidCode
values(13 , '133 % Child - Citizen/LPR/ PRUCOL - Full Scope', '72')
insert CalSAWSAidCode
values(14 , '133 % Child - Undocs/Non Immigrants - ESO', '74')
insert CalSAWSAidCode
values(15 , '133% Child - Excess Property - ESO', '8N')
insert CalSAWSAidCode
values(16 , '133% Child - Excess Property - Full Scope', '8P')
insert CalSAWSAidCode
values(17 , '19-64 Year Old County Inmate - 0-138% - Limited Scope - No SOC', 'N7')
insert CalSAWSAidCode
values(18 , '19-64 Year Old County Inmate - 0-138% - Restricted Scope - No SOC', 'N8')
insert CalSAWSAidCode
values(19 , '19-64 Year Old State Inmate - 0-138% - Limited Scope - No SOC', 'N5')
insert CalSAWSAidCode
values(20 , '19-64 Year Old State Inmate - 0-138% - Restricted Scope - No SOC', 'N6')
insert CalSAWSAidCode
values(21 , '1931(b) Foster Care', '4L')
insert CalSAWSAidCode
values(22 , '20 - Blind - SSI/SSP', '20')
insert CalSAWSAidCode
values(23 , '250% Working Disabled - Full Scope', '6G')
insert CalSAWSAidCode
values(24 , '2A - Abandoned Baby', '2A')
insert CalSAWSAidCode
values(25 , '2P - ARC only', '2P')
insert CalSAWSAidCode
values(26 , '2R - ARC only for NMDs', '2R')
insert CalSAWSAidCode
values(27 , '2S - ARC with federal CalWORKs', '2S')
insert CalSAWSAidCode
values(28 , '2T - ARC with State CalWORKs', '2T')
insert CalSAWSAidCode
values(29 , '2U - ARC with State CalWORKs for NMDs', '2U')
insert CalSAWSAidCode
values(30 , '43 - FC Extended (State) beyond age 18', '43')
insert CalSAWSAidCode
values(31 , '49 - FC Extended (Federal) beyond age 18', '49')
insert CalSAWSAidCode
values(32 , '4N - Extended CalWORKS for Non Minor Dependents', '4N')
insert CalSAWSAidCode
values(33 , '4P - CW Family Reunification-All Families', '4P')
insert CalSAWSAidCode
values(34 , '4R - CW Family Reunification-Two Parent', '4R')
insert CalSAWSAidCode
values(35 , '5J - SB87 Pending SP-DDSD - No SOC - Restricted', '5J')
insert CalSAWSAidCode
values(36 , '5R - SB87 Pending SP-DDSD - SOC', '5R')
insert CalSAWSAidCode
values(37 , '60 - Disabled - SSI/SSP', '60')
insert CalSAWSAidCode
values(38 , '60-Day Postpartum - Pregnancy Related Services', '76')
insert CalSAWSAidCode
values(39 , '6J - SB87 Pending SP-DDSD - No SOC', '6J')
insert CalSAWSAidCode
values(40 , '6R - SB87 Pending SP-DDSD - SOC', '6R')
insert CalSAWSAidCode
values(41 , '90 – GA/GR Employable, Independent Living, Family, Group ', '90')
insert CalSAWSAidCode
values(42 , '91 – GA/GR Employable, Independent Living, Single ', '91')
insert CalSAWSAidCode
values(43 , '92 – GA/GR Employable, Facility, Family Group', '92')
insert CalSAWSAidCode
values(44 , '93 – GA/GR Employable, Facility, Single ', '93')
insert CalSAWSAidCode
values(45 , '94 – GA/GR Unemployable, Independent Living, Family Group', '94')
insert CalSAWSAidCode
values(46 , '95 – GA/GR Unemployable, Independent Living, Single ', '95')
insert CalSAWSAidCode
values(47 , '96 – GA/GR Unemployable, Facility, Family Group', '96')
insert CalSAWSAidCode
values(48 , '97 – GA/GR Unemployable, Facility, Single ', '97')
insert CalSAWSAidCode
values(49 , '98 – GA/GR Aid In Kind', '98')
insert CalSAWSAidCode
values(50 , '9B – GA/GR Indigent Burial ', '9B')
insert CalSAWSAidCode
values(51 , '9A – GA/GR SF AGEX', '9A')
insert CalSAWSAidCode
values(52 , '9G – GA/GR Return to Residence', '9G')
insert CalSAWSAidCode
values(53 , '9H – GA/GR Healthy Families Child ', '9H')
insert CalSAWSAidCode
values(54 , '9I – GA/GR SF CALM ', '9I')
insert CalSAWSAidCode
values(55 , '9J – GA/GR SF PAES', '9J')
insert CalSAWSAidCode
values(56 , 'RE – GA/GR SF Retention ', 'RE')
insert CalSAWSAidCode
values(57 , 'AFDC Medically Needy - No SOC', '34')
insert CalSAWSAidCode
values(58 , 'AFDC Medically Needy - SOC', '37')
insert CalSAWSAidCode
values(59 , 'AFDC-1931( B) - Emergency/Pregnancy Services Only', '3V')
insert CalSAWSAidCode
values(60 , 'AFDC-1931( B) Full Scope', '3N')
insert CalSAWSAidCode
values(61 , 'AFDC-Foster Care (Federal)', '42')
insert CalSAWSAidCode
values(62 , 'AFDC-Foster Care (State Only)', '40')
insert CalSAWSAidCode
values(63 , 'Accelerated Enrollment of Children', '8E')
insert CalSAWSAidCode
values(64 , 'Access for Infants and Mothers 200-300 percent', '0C')
insert CalSAWSAidCode
values(65 , 'Additional Transitional Medi-Cal (Second 6 months)', '59')
insert CalSAWSAidCode
values(66 , 'Adoption Assistance - Extended - Federal', '07')
insert CalSAWSAidCode
values(67 , 'Adoption Assistance - Federal', '03')
insert CalSAWSAidCode
values(68 , 'Adoption Assistance - State Only', '04')
insert CalSAWSAidCode
values(69 , 'Aid to Adoptions - Out of State Adoption', '4A')
insert CalSAWSAidCode
values(70 , 'Aid to Disabled - Medically Needy - SOC', '67')
insert CalSAWSAidCode
values(71 , 'Aid to Disabled - Pickle Eligible', '66')
insert CalSAWSAidCode
values(72 , 'Aid to Disabled Widow/ ers', '36')
insert CalSAWSAidCode
values(73 , 'Aid to the Aged - Long Term Care', '13')
insert CalSAWSAidCode
values(74 , 'Aid to the Aged - Medically Needy - No SOC', '14')
insert CalSAWSAidCode
values(75 , 'Aid to the Aged - Medically Needy - SOC', '17')
insert CalSAWSAidCode
values(76 , 'Aid to the Aged - Pickle Eligibles', '16')
insert CalSAWSAidCode
values(77 , 'Aid to the Blind - Long Term Care', '23')
insert CalSAWSAidCode
values(78 , 'Aid to the Blind - Medically Needy - No SOC', '24')
insert CalSAWSAidCode
values(79 , 'Aid to the Blind - Medically Needy- SOC', '27')
insert CalSAWSAidCode
values(80 , 'Aid to the Blind - Pickle Eligibles', '26')
insert CalSAWSAidCode
values(81 , 'Aid to the Disabled - Medically Needy - No SOC', '64')
insert CalSAWSAidCode
values(82 , 'Anti-Rejection Medicine - State Only', '77')
insert CalSAWSAidCode
values(83 , 'CAPI - Aged', '1A')
insert CalSAWSAidCode
values(84 , 'CAPI - Non Qualified', '6K')
insert CalSAWSAidCode
values(85 , 'CAPI - Sponsored', '6M')
insert CalSAWSAidCode
values(86 , 'CAPI-LimitedTerm', '6T')
insert CalSAWSAidCode
values(87 , 'CHDP', '8Y')
insert CalSAWSAidCode
values(88 , 'CHDP Gateway Deemed Infant - NO SOC', '8U')
insert CalSAWSAidCode
values(89 , 'CHDP Gateway Deemed Infant - SOC', '8V')
insert CalSAWSAidCode
values(90 , 'CHDP Gateway HF', '8X')
insert CalSAWSAidCode
values(91 , 'CHDP Gateway Medi-Cal', '8W')
insert CalSAWSAidCode
values(92 , 'CMSP - Full Scope - No Share of Cost', '84')
insert CalSAWSAidCode
values(93 , 'CMSP - Full Scope - Share of Cost', '85')
insert CalSAWSAidCode
values(94 , 'CMSP - Long Term Care', '8F')
insert CalSAWSAidCode
values(95 , 'CMSP - Non-Fed - Full Scope - No Share of Cost', '88')
insert CalSAWSAidCode
values(96 , 'CMSP - Non-Fed - Share of Cost', '89')
insert CalSAWSAidCode
values(97 , 'CMSP - Restricted Benefits', '50')
insert CalSAWSAidCode
values(98 , 'CalFresh Trafficking and Crime Victims Assistance Program', 'R2')
insert CalSAWSAidCode
values(99 , 'CalWORKs - Diversion -All Families (State Only)', '3X')
insert CalSAWSAidCode
values(100, 'CalWORKs - Safety Net/Fleeing Felon/Long-Term WTW Sanction - Non-Two Parent', 'K1')
insert CalSAWSAidCode
values(101, 'CalWORKs - Safety Net/Fleeing Felon/Long-Term WTW Sanction - Two Parent', '3F')
insert CalSAWSAidCode
values(102, 'CalWORKs - TANF - Timed Out (State)', '3W')
insert CalSAWSAidCode
values(103, 'CalWORKs - Timed Out - Safety Net Two Parent (Prior to 12/2013)', '3C')
insert CalSAWSAidCode
values(104, 'CalWORKs - Timed Out Safety Net  All Families (Prior to 12/2013)', '3A')
insert CalSAWSAidCode
values(105, 'CalWORKs -All Families (Mixed)', '3E')
insert CalSAWSAidCode
values(106, 'CalWORKs -All Families- Exempt MAP (Federal)', '3P')
insert CalSAWSAidCode
values(107, 'CalWORKs -Diversion -All Families (Federal)', '3J')
insert CalSAWSAidCode
values(108, 'CalWORKs -Diversion -Two Parent (Federal)', '3K')
insert CalSAWSAidCode
values(109, 'CalWORKs -Diversion -Two Parent (State Only)', '3Y')
insert CalSAWSAidCode
values(110, 'CalWORKs -TANF Timed Out - All Families (Fed)', '30')
insert CalSAWSAidCode
values(111, 'CalWORKs -TANF Timed Out -All Families (State)', '32')
insert CalSAWSAidCode
values(112, 'CalWORKs -Two Parent (Federal)', '35')
insert CalSAWSAidCode
values(113, 'CalWORKs -Two Parent (State)', '3U')
insert CalSAWSAidCode
values(114, 'CalWORKs -Two Parent - State Only', '3M')
insert CalSAWSAidCode
values(115, 'CalWORKs -Zero Parent (Federal)', '33')
insert CalSAWSAidCode
values(116, 'CalWORKs -Zero Parent (Mixed)', '3H')
insert CalSAWSAidCode
values(117, 'CalWORKs -Zero Parent (State Only)', '3G')
insert CalSAWSAidCode
values(118, 'CalWORKs -Zero Parent - Exempt MAP (Federal)', '3R')
insert CalSAWSAidCode
values(119, 'CalWORKs All Families (State Only)', '3L')
insert CalSAWSAidCode
values(120, 'CalWORKs Trafficking and Crime Victims Assistance Program', 'R1')
insert CalSAWSAidCode
values(121, 'Child 1-19 ACA CHIP Premium Full Scope', 'E5')
insert CalSAWSAidCode
values(122, 'Child 1-6 - 0-142% - Citizen - Full Scope', 'P7')
insert CalSAWSAidCode
values(123, 'Child 1-6 - 0-142% - Undocumented - Restricted Scope', 'P8')
insert CalSAWSAidCode
values(124, 'Child 1-6 - 142-160% - Citizen - Full Scope', 'T4')
insert CalSAWSAidCode
values(125, 'Child 1-6 - 142-160% - Undocumented - Restricted Scope', 'T9')
insert CalSAWSAidCode
values(126, 'Child 1-6 - 160-266% - Citizen - Full Scope', 'T3')
insert CalSAWSAidCode
values(127, 'Child 1-6 - 160-266% - Undocumented - Restricted Scope', 'T8')
insert CalSAWSAidCode
values(128, 'Child 6-19 - 0-133% - Citizen - Full Scope', 'P5')
insert CalSAWSAidCode
values(129, 'Child 6-19 - 0-133% - Undocumented - Restricted Scope', 'P6')
insert CalSAWSAidCode
values(130, 'Child 6-19 - 108-133% - Citizen - Full Scope', 'M5')
insert CalSAWSAidCode
values(131, 'Child 6-19 - 108-133% - Undocumented - Restricted Scope', 'M6')
insert CalSAWSAidCode
values(132, 'Child 6-19 - 130-160% - Undocumented - Restricted Scope', 'T7')
insert CalSAWSAidCode
values(133, 'Child 6-19 - 133-160% - Citizen - Full Scope', 'T2')
insert CalSAWSAidCode
values(134, 'Child 6-19 - 160-266% - Citizen - Full Scope', 'T1')
insert CalSAWSAidCode
values(135, 'Child 6-19 - 160-266% - Undocumented - Restricted Scope', 'T6')
insert CalSAWSAidCode
values(136, 'Citizen/Lawfully Present Adult 19 through 64 Years with Person Disability Indicator', 'L6')
insert CalSAWSAidCode
values(137, 'Compassionate Release LTC Aged County Full Scope', 'J5')
insert CalSAWSAidCode
values(138, 'Compassionate Release LTC Aged County Restricted', 'J6')
insert CalSAWSAidCode
values(139, 'Compassionate Release LTC Disabled County Full Scope', 'J7')
insert CalSAWSAidCode
values(140, 'Compassionate Release LTC Disabled County Restricted', 'J8')
insert CalSAWSAidCode
values(141, 'Compassionate Release No SOC County Full Scope', 'J1')
insert CalSAWSAidCode
values(142, 'Compassionate Release No SOC State Restricted', 'G9')
insert CalSAWSAidCode
values(143, 'Compassionate Release SOC County Full Scope', 'J2')
insert CalSAWSAidCode
values(144, 'Continuing TMC (Second 6 Months)-Emergency/Pregnan', '5T')
insert CalSAWSAidCode
values(145, 'Continuous Eligibility for Children', '7J')
insert CalSAWSAidCode
values(146, 'Continuous Eligibility for Children - ESO', '7K')
insert CalSAWSAidCode
values(147, 'County Funded Foster Care', '45')
insert CalSAWSAidCode
values(148, 'County Juvenile Inmate Inpatient Hospital+ Inpatient MH', 'G5')
insert CalSAWSAidCode
values(149, 'County Juvenile Inmate Undoc, ESO Inpatient Hospital, MH & Pregnancy', 'G6')
insert CalSAWSAidCode
values(150, 'County Juvenile Inmate Undoc, SOC, ESO Inpatient Hospital, MH & Pregnancy', 'G8')
insert CalSAWSAidCode
values(151, 'County Juvenile Inmate, SOC Inpatient Hospital & Inpatient MH', 'G7')
insert CalSAWSAidCode
values(152, 'County Medical Probation No SOC Restricted', 'J3')
insert CalSAWSAidCode
values(153, 'County Medical Probation SOC Restricted', 'J4')
insert CalSAWSAidCode
values(154, 'Covered CA Above 400% FPL', 'X7')
insert CalSAWSAidCode
values(155, 'Covered CA CSR Only', 'X6')
insert CalSAWSAidCode
values(156, 'Covered CA Cost Sharing 100-300%', 'X5')
insert CalSAWSAidCode
values(157, 'Covered CA MC Ineligible Under 100%', 'X8')
insert CalSAWSAidCode
values(158, 'Covered CA Narrow Bridge', 'X9')
insert CalSAWSAidCode
values(159, 'Covered CA Subsidized 100-150%', 'X2')
insert CalSAWSAidCode
values(160, 'Covered CA Subsidized 151-200%', 'X3')
insert CalSAWSAidCode
values(161, 'Covered CA Subsidized 201-250%', 'X4')
insert CalSAWSAidCode
values(162, 'Covered CA Subsidized 250-400%', 'X1')
insert CalSAWSAidCode
values(163, 'Craig Continued Eligibility for the Aged', '1E')
insert CalSAWSAidCode
values(164, 'Craig Continued Eligibility for the Blind', '2E')
insert CalSAWSAidCode
values(165, 'Craig Continued Eligibility for the Disabled', '6E')
insert CalSAWSAidCode
values(167, 'DDS Waiver - No SOC', '6V')
insert CalSAWSAidCode
values(168, 'DDS Waiver - SOC', '6W')
insert CalSAWSAidCode
values(169, 'Dialysis/Dialysis Supplement', '71')
insert CalSAWSAidCode
values(170, 'Disabled Adult Child( ren) - Blind', '6A')
insert CalSAWSAidCode
values(171, 'Disabled Adult Child( ren) - Disabled', '6C')
insert CalSAWSAidCode
values(172, 'Edwards v. Kizer Continuing Medi-Cal Eligibility', '38')
insert CalSAWSAidCode
values(173, 'Electronic Theft Replacement Cash Benefit (ETRCB) Aid Code', '99')
insert CalSAWSAidCode
values(174, 'Emergency Assistance - Foster Care', '5K')
insert CalSAWSAidCode
values(175, 'Emergency Assistance - Foster Care NonFed', '5L')
insert CalSAWSAidCode
values(176, 'F0 - HCCI - LIHP', 'F0')
insert CalSAWSAidCode
values(177, 'F3 - MC County Inmate Inpatient Hospital Only - No SOC', 'F3')
insert CalSAWSAidCode
values(178, 'F4 - MC Undoc County Inmates - No SOC', 'F4')
insert CalSAWSAidCode
values(179, 'F5 - MCE ST Inmates', 'F5')
insert CalSAWSAidCode
values(180, 'F6 - MCE CO Inmates', 'F6')
insert CalSAWSAidCode
values(181, 'F7 - MCE Existing', 'F7')
insert CalSAWSAidCode
values(182, 'F8 - LIHP - MCE', 'F8')
insert CalSAWSAidCode
values(183, 'F9 - HCCI LIHP - CI', 'F9')
insert CalSAWSAidCode
values(184, 'FPL - Disabled - ESO/Pregnancy', '6U')
insert CalSAWSAidCode
values(185, 'FPL 19-64 Year Old at or below 138% Full Scope', 'M1')
insert CalSAWSAidCode
values(186, 'FPL 19-64 Year Old at or below 138% Restricted Scope', 'M2')
insert CalSAWSAidCode
values(187, 'FPL Child 1-6 -142% Full Scope', 'H7')
insert CalSAWSAidCode
values(188, 'FPL Child 1-6 143-266% Full Scope', 'H9')
insert CalSAWSAidCode
values(189, 'FPL Child 6-19 - 0-133% Full Scope', 'H8')
insert CalSAWSAidCode
values(190, 'FPL Child 6-19 133-266% Full Scope', 'H0')
insert CalSAWSAidCode
values(191, 'FPL Disabled - Full Scope .', '6H')
insert CalSAWSAidCode
values(192, 'FPL Infant - Above 267-322% Full Scope', 'E7')
insert CalSAWSAidCode
values(193, 'FPL Infant 209-266% Full Scope', 'H6')
insert CalSAWSAidCode
values(194, 'Federal AAP Cash Subsidy from Out-of-State', '06')
insert CalSAWSAidCode
values(195, 'Federal Poverty Level - Aged- Emergency Services', '1U')
insert CalSAWSAidCode
values(196, 'Federal Poverty Level - Aged- Full Scope - No SOC', '1H')
insert CalSAWSAidCode
values(197, 'Federal Poverty Level -Blind- Full Scope - No SOC', '2H')
insert CalSAWSAidCode
values(198, 'Federally Funded FC Benefits from Out-of-State', '46')
insert CalSAWSAidCode
values(199, 'Foster Care - Cuban/Haitian-Entrants', '08')
insert CalSAWSAidCode
values(200, 'Foster Care Continuing Medi-Cal', '4M')
insert CalSAWSAidCode
values(201, 'HFP to Medi-Cal Transitional PE-No Premium', '5C')
insert CalSAWSAidCode
values(202, 'HFP to Medi-Cal Transitional PE-Premium Payment', '5D')
insert CalSAWSAidCode
values(203, 'Hospital PE Adults - 0-138%', 'P3')
insert CalSAWSAidCode
values(204, 'Hospital PE Infant - 0-208%', 'P1')
insert CalSAWSAidCode
values(205, 'Hospital PE Parent Caretaker Relatives - 0-109%', 'P2')
insert CalSAWSAidCode
values(206, 'Hospital PE Pregnant Women - 0-213%', 'P4')
insert CalSAWSAidCode
values(207, 'IE Medi-Cal Member - Non Sneede MFBU', 'IE')
insert CalSAWSAidCode
values(208, 'IHSS Plus Waiver', '2L')
insert CalSAWSAidCode
values(209, 'IHSS Residual', '2N')
insert CalSAWSAidCode
values(210, 'IHSS-Community First Choice Option', '2K')
insert CalSAWSAidCode
values(211, 'In Home Operations Waiver - No SOC', '6X')
insert CalSAWSAidCode
values(212, 'In Home Operations Waiver - SOC', '6Y')
insert CalSAWSAidCode
values(213, 'Income Disregard - 200% -Infant Full Scope', '47')
insert CalSAWSAidCode
values(214, 'Income Disregard - 200% OBRA', '69')
insert CalSAWSAidCode
values(215, 'Income Disregard 200% - Pregnant Women - Undocs', '48')
insert CalSAWSAidCode
values(216, 'Income Disregard 200% - Pregnant Women -Citizen/PR', '44')
insert CalSAWSAidCode
values(217, 'Infant - 0-208% - Citizen - Full Scope', 'P9')
insert CalSAWSAidCode
values(218, 'Infant - 0-208% - Undocumented - Restricted Scope', 'P0')
insert CalSAWSAidCode
values(219, 'Infant - 208-266% - Citizen - Full Scope', 'T5')
insert CalSAWSAidCode
values(220, 'Infant - 208-266% - Undocumented - Restricted Scope', 'T0')
insert CalSAWSAidCode
values(221, 'Infant-19 ACA CHIP Lawful Citizen Full Scope', 'E2')
insert CalSAWSAidCode
values(222, 'Infant-19 ACA CHIP Undocumented Restricted Scope', 'E4')
insert CalSAWSAidCode
values(223, 'Initial Transitional Medi-Cal', '39')
insert CalSAWSAidCode
values(224, 'Initial Transitional Medi-Cal (First 6 months)', '3T')
insert CalSAWSAidCode
values(225, 'Kin-GAP (Federal)', '4T')
insert CalSAWSAidCode
values(226, 'Kin-GAP (State Only)', '4F')
insert CalSAWSAidCode
values(227, 'Kin-GAP (State Only) for children beyond age 18 due to a disability', '4G')
insert CalSAWSAidCode
values(228, 'Kin-GAP Extended (Federal)', '4S')
insert CalSAWSAidCode
values(229, 'Kin-GAP Extended (State)', '4W')
insert CalSAWSAidCode
values(230, 'Long Term Care - Aged - SOC - Undocs and Non Immigrants', 'D3')
insert CalSAWSAidCode
values(231, 'Long Term Care - Aged - no SOC - Undocs and Non Immigrants', 'D2')
insert CalSAWSAidCode
values(232, 'Long Term Care - Blind - No SOC - Undocs and Non Immigrants', 'D4')
insert CalSAWSAidCode
values(233, 'Long Term Care - Blind - SOC - Undocs and Non Immigrants', 'D5')
insert CalSAWSAidCode
values(234, 'Long Term Care - Disabled', '63')
insert CalSAWSAidCode
values(235, 'Long Term Care - Disabled - No SOC - Undocs and Non Immigrants', 'D6')
insert CalSAWSAidCode
values(236, 'Long Term Care - Disabled - SOC - Undocs and Non Immigrants', 'D7')
insert CalSAWSAidCode
values(237, 'Long Term Care - MI - Undocs and Non Immigrants', '55')
insert CalSAWSAidCode
values(238, 'MC Four Month Continuing - Emergency/Pregnancy Ser', '5W')
insert CalSAWSAidCode
values(239, 'MC No SOC State Inmates', 'F1')
insert CalSAWSAidCode
values(240, 'MC SOC State Inmates', 'G1')
insert CalSAWSAidCode
values(241, 'MC Targeted Low Income FPL Child 1-6 133-150%', 'H2')
insert CalSAWSAidCode
values(242, 'MC Targeted Low Income FPL Child 1-6 150-250% Premium', 'H3')
insert CalSAWSAidCode
values(243, 'MC Targeted Low Income FPL Child 6-19 100-150%', 'H4')
insert CalSAWSAidCode
values(244, 'MC Targeted Low Income FPL Child 6-19 150-250% Premium', 'H5')
insert CalSAWSAidCode
values(245, 'MI - Child - SOC', '83')
insert CalSAWSAidCode
values(246, 'MI - Child No SOC', '82')
insert CalSAWSAidCode
values(247, 'MI - Confirmed Pregnancy - No SOC', '86')
insert CalSAWSAidCode
values(248, 'MI - Confirmed Pregnancy - SOC', '87')
insert CalSAWSAidCode
values(249, 'MSSP with a SOC', '1Y')
insert CalSAWSAidCode
values(250, 'MSSP without a SOC', '1X')
insert CalSAWSAidCode
values(251, 'Medi-Cal County Inmate SOC Inpatient Hospital Only', 'G3')
insert CalSAWSAidCode
values(252, 'Medi-Cal County Inmate Undoc SOC Inpatient Hospital Pregnancy+ ESO', 'G4')
insert CalSAWSAidCode
values(253, 'Medi-Cal Four Month Continuing', '54')
insert CalSAWSAidCode
values(254, 'Medi-Cal Targeted Low Income FPL for Infants', 'H1')
insert CalSAWSAidCode
values(255, 'Medically Indigent - Child - No SOC - Undocs and Non Immigrants', 'C9')
insert CalSAWSAidCode
values(256, 'Medically Indigent - Child - SOC - Undocs and Non Immigrants', 'D1')
insert CalSAWSAidCode
values(257, 'Medically Indigent - Long Term Care', '53')
insert CalSAWSAidCode
values(258, 'Medically Indigent - Pregnant Women - No SOC - Undocs & Non Immigrants', 'D8')
insert CalSAWSAidCode
values(259, 'Medically Indigent - Pregnant Women - SOC - Undocs & Non Immigrants', 'D9')
insert CalSAWSAidCode
values(260, 'Medically Needy - AFDC - No SOC - Undocs and Non Immigrants', 'C5')
insert CalSAWSAidCode
values(261, 'Medically Needy - AFDC - SOC - Undocs and Non Immigrants', 'C6')
insert CalSAWSAidCode
values(262, 'Medically Needy - Aged - No SOC -  Undocs and Non Immigrants', 'C1')
insert CalSAWSAidCode
values(263, 'Medically Needy - Aged - SOC - Undocs and Non Immigrants', 'C2')
insert CalSAWSAidCode
values(264, 'Medically Needy - Blind - No SOC - Undocs and Non Immigrants', 'C3')
insert CalSAWSAidCode
values(265, 'Medically Needy - Blind - SOC - Undocs and Non Immigrants', 'C4')
insert CalSAWSAidCode
values(266, 'Medically Needy - Disabled - No SOC - Undocs and Non Immigrants', 'C7')
insert CalSAWSAidCode
values(267, 'Medically Needy - Disabled - SOC - Undocs and Non Immigrants', 'C8')
insert CalSAWSAidCode
values(268, 'Minor Consent (12 -21) Family Planning', '7M')
insert CalSAWSAidCode
values(269, 'Minor Consent (12 -21) Outpatient Mental Health', '7P')
insert CalSAWSAidCode
values(270, 'Minor Consent (under 12) Sexual Assault', '7R')
insert CalSAWSAidCode
values(271, 'Minor Consent (under 21) Pregnancy', '7N')
insert CalSAWSAidCode
values(272, 'N0 - County Inmate LIHP/MCE Transition to Medi-Cal', 'N0')
insert CalSAWSAidCode
values(273, 'New Adult Group LTC', 'E3')
insert CalSAWSAidCode
values(274, 'No SOC MC for Undocumented State Inmates', 'F2')
insert CalSAWSAidCode
values(275, 'Non Assistance CalFresh', '09')
insert CalSAWSAidCode
values(276, 'One-Month Healthy Families Bridge - Child', '7X')
insert CalSAWSAidCode
values(277, 'One-Month Healthy Families Bridge - Unverified Citizenship Child', 'E1')
insert CalSAWSAidCode
values(278, 'One-Month Healthy Families Bridge -Adult', '7Y')
insert CalSAWSAidCode
values(279, 'Parent Caretaker Relative - at or below 125% - Citizen - Full Scope', 'M3')
insert CalSAWSAidCode
values(280, 'Parent Caretaker Relative - at or below 125% - Restricted Scope', 'M4')
insert CalSAWSAidCode
values(281, 'Parental Hyperalimentation/TPN Supplement', '73')
insert CalSAWSAidCode
values(282, 'Personal Care Services', '2M')
insert CalSAWSAidCode
values(283, 'Pregnant Women - 60% - Citizen/Lawful - Full Scope', 'M7')
insert CalSAWSAidCode
values(284, 'Pregnant Women - 60% - Undocumented - Limited Scope', 'M8')
insert CalSAWSAidCode
values(285, 'Pregnant Women - 60-213% - Citiz/Lawful - Limited', 'M9')
insert CalSAWSAidCode
values(286, 'Pregnant Women - 60-213% - Undocumented - Limited Scope', 'M0')
insert CalSAWSAidCode
values(287, 'Presumptive Eligibility for Former Foster Care Children', '4E')
insert CalSAWSAidCode
values(288, 'Probation Emergency Assistance', '4K')
insert CalSAWSAidCode
values(289, 'Qualified Individual 1 - 135%', '8D')
insert CalSAWSAidCode
values(290, 'Qualified Medicare Beneficiary', '80')
insert CalSAWSAidCode
values(291, 'Qualified Working Disabled Individuals Program', '8A')
insert CalSAWSAidCode
values(292, 'R4-Work Incentive Nutritional Supplement Program Non-Two-Parent', 'R4')
insert CalSAWSAidCode
values(293, 'R5- Work Incentive Nutritional Supplement Two-Parent', 'R5')
insert CalSAWSAidCode
values(294, 'R6- Work Incentive Nutritional Supplement California Food Assistance Program', 'R6')
insert CalSAWSAidCode
values(295, 'R7- Work Incentive Nutritional Supplement Non-Two Parent Transitional CalFresh', 'R7')
insert CalSAWSAidCode
values(296, 'R8- Work Incentive Nutritional Supplement Two-Parent Transitional CalFresh', 'R8')
insert CalSAWSAidCode
values(297, 'R9- Work Incentive Nutritional Supplement Transitional California Food Assistance Program', 'R9')
insert CalSAWSAidCode
values(298, 'RR Medi-Cal Member - Sneede MBU', 'RR')
insert CalSAWSAidCode
values(299, 'Refugee Cash Assistance - Exempt MAP', '01')
insert CalSAWSAidCode
values(300, 'Refugee Cash Assistance Trafficking and Crime Victims Assistance Program', '1V')
insert CalSAWSAidCode
values(301, 'Refugee/Entrant Medical Assistance', '02')
insert CalSAWSAidCode
values(302, 'SOC MC for Undocumented State Inmates', 'G2')
insert CalSAWSAidCode
values(303, 'Seriously Emotionally Disturbed - Non Emergency As', '05')
insert CalSAWSAidCode
values(304, 'Simplified Qualified Medicare Beneficiary', '8C')
insert CalSAWSAidCode
values(305, 'Terminated as of 10/1/2003 - Extended TMC(2nd Year) 19 & older - Emergency/Pregnancy', '5Y')
insert CalSAWSAidCode
values(306, 'Terminated as of 10/1/2003 - Extended TMC(2nd Year) 19 & older - Full Scope', '5X')
insert CalSAWSAidCode
values(307, 'Title XIX, CalFRESH Parents aged 19 through 64 years of age, not blind or disabled, without Medi-Cal or LIHP', '7S')
insert CalSAWSAidCode
values(308, 'Title XIX, CalFresh adults from 19 through 64 years of age who are citizens or lawfully present and neither blind nor disabled with no Share of Cost (SOC)', '7U')
insert CalSAWSAidCode
values(309, 'Title XIX, children under age 19 not blind or disabled, full scope no cost Medi-Cal, no Share of Cost (SOC)', '7W')
insert CalSAWSAidCode
values(310, 'Trafficking/Crime Program no SOC', '5V')
insert CalSAWSAidCode
values(311, 'Trafficking/Crime Program with a SOC', '7V')
insert CalSAWSAidCode
values(312, 'Trafficking/Crime Victim no SOC', '2V')
insert CalSAWSAidCode
values(313, 'Trafficking/Crime Victim with a SOC', '4V')
insert CalSAWSAidCode
values(314, 'Transitional CalFresh', '0F')
insert CalSAWSAidCode
values(315, 'Transitional Nutrition Benefit', '0H')
insert CalSAWSAidCode
values(316, 'Tuberculosis Treatment Program', '7H')
insert CalSAWSAidCode
values(317, 'Undocumented Adult 19 through 64 Years with Person Disability Indicator', 'L7')
insert CalSAWSAidCode
values(318, 'Voluntary Placement', '4C')

go








/*   
     system:        CalSAWS Conversion
     procedure:     CalSAWSLanguageCode.tab
     written by:    Craig Deane
     date written:  12/3/2020
     database:      welcoll
     function:      Creates the Language table that holds all of the CalSAWS Language Codes
     modified by:   
     changes:       
 */

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSLanguageCode') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSLanguageCode
              END
Go

CREATE TABLE dbo.CalSAWSLanguageCode
       (number	integer,
	description	varchar(255),
	calsaws_code	char(2),
	PRIMARY KEY (number)
 )
go

grant select, insert, update, delete on CalSAWSLanguageCode to public
go

insert CalSAWSLanguageCode
values(1  , 'English', '03')
insert CalSAWSLanguageCode
values(2  , 'Spanish', '02')
insert CalSAWSLanguageCode
values(3  , 'Afghani', '35')
insert CalSAWSLanguageCode
values(4  , 'American Sign Language', '01')
insert CalSAWSLanguageCode
values(5  , 'Amharic', '43')
insert CalSAWSLanguageCode
values(6  , 'Arabic', '25')
insert CalSAWSLanguageCode
values(7  , 'Aramaic', '44')
insert CalSAWSLanguageCode
values(8  , 'Armenian', '13')
insert CalSAWSLanguageCode
values(9  , 'Assyrian', '34')
insert CalSAWSLanguageCode
values(10 , 'Bengali', '30')
insert CalSAWSLanguageCode
values(11 , 'Bosnian', '40')
insert CalSAWSLanguageCode
values(12 , 'Cambodian', '12')
insert CalSAWSLanguageCode
values(13 , 'Cantonese (Chinese)', '10')
insert CalSAWSLanguageCode
values(14 , 'Croatian', '41')
insert CalSAWSLanguageCode
values(15 , 'Egyptian', '42')
insert CalSAWSLanguageCode
values(16 , 'Farsi', '28')
insert CalSAWSLanguageCode
values(17 , 'French', '20')
insert CalSAWSLanguageCode
values(18 , 'German', '32')
insert CalSAWSLanguageCode
values(19 , 'Greek', '45')
insert CalSAWSLanguageCode
values(20 , 'Hebrew', '19')
insert CalSAWSLanguageCode
values(21 , 'Hindi', '31')
insert CalSAWSLanguageCode
values(22 , 'Hmong', '16')
insert CalSAWSLanguageCode
values(23 , 'Ilocano', '14')
insert CalSAWSLanguageCode
values(24 , 'Indonesian', '46')
insert CalSAWSLanguageCode
values(25 , 'Italian', '24')
insert CalSAWSLanguageCode
values(26 , 'Japanese', '04')
insert CalSAWSLanguageCode
values(27 , 'Korean', '05')
insert CalSAWSLanguageCode
values(28 , 'Lao', '17')
insert CalSAWSLanguageCode
values(29 , 'Mandarin (Chinese)', '11')
insert CalSAWSLanguageCode
values(30 , 'Mien', '15')
insert CalSAWSLanguageCode
values(31 , 'Other Chinese Language', '08')
insert CalSAWSLanguageCode
values(32 , 'Other Non-English', '07')
insert CalSAWSLanguageCode
values(33 , 'Other Sign Language', '09')
insert CalSAWSLanguageCode
values(34 , 'Persian', '36')
insert CalSAWSLanguageCode
values(35 , 'Polish', '21')
insert CalSAWSLanguageCode
values(36 , 'Portuguese', '23')
insert CalSAWSLanguageCode
values(37 , 'Punjabi', '33')
insert CalSAWSLanguageCode
values(38 , 'Romanian', '37')
insert CalSAWSLanguageCode
values(39 , 'Russian', '22')
insert CalSAWSLanguageCode
values(40 , 'Samoan', '26')
insert CalSAWSLanguageCode
values(41 , 'Serbian', '39')
insert CalSAWSLanguageCode
values(42 , 'Tagalog, Filipino', '06')
insert CalSAWSLanguageCode
values(43 , 'Thai', '27')
insert CalSAWSLanguageCode
values(44 , 'Turkish', '18')
insert CalSAWSLanguageCode
values(45 , 'Urdu', '38')
insert CalSAWSLanguageCode
values(46 , 'Vietnamese', '29')


go








/*   
     	system:        	CalSAWS Conversion
     	procedure:     	CalSAWSProgramCode.tab
     	written by:    	Craig Deane
     	date written:  	9/2/2020
     	database:      	welcoll
     	function:      	Creates the CalSAWSProgramCode table that holds all of the CalSAWS Program Codes
     	modified by:   	Craig Deane 1/11/2022 Version 2.1
     	changes:       	Added new codes for FSD 2.1
     	modified by:   	Craig Deane 4/5/2022 Version 2.2
     	changes:	Updated for FSD 2.2	
	modified by:   	Craig Deane 9/29/2022 Version 2.3
     	changes:	Updated for FSD 2.3
	modified by:   	Craig Deane 4/21/2023 Version 2.6
     	changes:	Updated for FSD 2.6
 */

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSProgramCode') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSProgramCode
              END
Go

CREATE TABLE dbo.CalSAWSProgramCode
       (number	integer,
	description	varchar(255),
	calsaws_code	char(2),
	PRIMARY KEY (number)
 )
go

grant select, insert, update, delete on CalSAWSProgramCode to public
go

insert CalSAWSProgramCode
values(1  , 'Adoptions Assistance Program (AAP)', 'AA')
insert CalSAWSProgramCode
values(2  , 'Adult Protective Services', 'AS')
insert CalSAWSProgramCode
values(3  , 'CalFresh', 'FS')
insert CalSAWSProgramCode
values(4  , 'Cal-Learn', 'CL')
insert CalSAWSProgramCode
values(5  , 'CalWORKs', 'CW')
insert CalSAWSProgramCode
values(6  , 'Cash Assistance Program for Immigrants (CAPI)', 'CP')
insert CalSAWSProgramCode
values(7  , 'CalFresh for Employment & Training (CFET)', 'FT')
insert CalSAWSProgramCode
values(8  , 'Child Care', 'CC')
insert CalSAWSProgramCode
values(9  , 'Child Protective Services', 'CS')
insert CalSAWSProgramCode
values(10 , 'Disaster CalFresh', 'DC')
insert CalSAWSProgramCode
values(11 , 'Diversion', 'DV')
insert CalSAWSProgramCode
values(12 , 'Food Distribution', 'FD')
insert CalSAWSProgramCode
values(13 , 'Foster Care', 'FC')
insert CalSAWSProgramCode
values(14 , 'GA/GR Automated Solution', 'GR')
insert CalSAWSProgramCode
values(15 , 'GA/GR Employment Services', 'GE')
insert CalSAWSProgramCode
values(16 , 'GA/GR Immediate Need ', 'GI')
insert CalSAWSProgramCode
values(17 , 'General Relief Opportunities for WORK (GROW)', 'GW')
insert CalSAWSProgramCode
values(18 , 'Homeless Assistance - Permanent', 'HP')
insert CalSAWSProgramCode
values(19 , 'Homeless Assistance - Temporary', 'HT')
insert CalSAWSProgramCode
values(20 , 'In-Home Supportive Services/CMIPS II', 'IH')
insert CalSAWSProgramCode
values(21 , 'Immediate Need', 'IN')
insert CalSAWSProgramCode
values(22 , 'IV-D Child Support', 'IV')
insert CalSAWSProgramCode
values(23 , 'Kin-GAP', 'KG')
insert CalSAWSProgramCode
values(24 , 'Linkages Adult Services', 'LS')
insert CalSAWSProgramCode
values(25 , 'Medi-Cal', 'MC')
insert CalSAWSProgramCode
values(26 , 'Multipurpose Senior Services', 'MS')
insert CalSAWSProgramCode
values(27 , 'Nutrition Benefit', 'NB')
insert CalSAWSProgramCode
values(28 , 'Personal Care Services Program', 'PE')
insert CalSAWSProgramCode
values(29 , 'Refugee Cash Assistance', 'RC')
insert CalSAWSProgramCode
values(30 , 'Refugee Employment Program', 'RE')
insert CalSAWSProgramCode
values(31 , 'SSI Only', 'SI')
insert CalSAWSProgramCode
values(32 , 'SSI/SSP', 'SS')
insert CalSAWSProgramCode
values(33 , 'SSP Only', 'SP')
insert CalSAWSProgramCode
values(34 , 'Welfare to Work', 'WT')

go








/*   
     system:        CalSAWS Conversion
     procedure:     CalSAWSRecoveryAccountCause.tab
     written by:    Craig Deane
     date written:  9/3/2020
     database:      welcoll
     function:      Creates the CalSAWSRecoveryAccountCause table that holds all of the CalSAWS Recovery Account Cause codes
     modified by:   Craig Deane 3/2/2023 FSD 2.5
     changes:       Added program_code_description and program_code to meet new matching requirement
 */

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSRecoveryAccountCause') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSRecoveryAccountCause
              END
Go

CREATE TABLE dbo.CalSAWSRecoveryAccountCause
       (number	integer,
	program_code_description	varchar(255),
	program_code			char(2),
	description	varchar(255),
	calsaws_code	char(2),
	PRIMARY KEY (number)
 )
go

grant select, insert, update, delete on CalSAWSRecoveryAccountCause to public
go


insert CalSAWSRecoveryAccountCause
values(1  , 'Adoptions Assistance Program', 'AA', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(2  , 'Adoptions Assistance Program', 'AA', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(3  , 'Adoptions Assistance Program', 'AA', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(4  , 'Adoptions Assistance Program', 'AA', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(5  , 'Adoptions Assistance Program', 'AA', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(6  , 'Adoptions Assistance Program', 'AA', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(7  , 'Adoptions Assistance Program', 'AA', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(8  , 'Adoptions Assistance Program', 'AA', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(9  , 'Adoptions Assistance Program', 'AA', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(10 , 'Adoptions Assistance Program', 'AA', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(11 , 'Adoptions Assistance Program', 'AA', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(12 , 'Adoptions Assistance Program', 'AA', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(13 , 'Adoptions Assistance Program', 'AA', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(14 , 'Adult Protective Services', 'AS', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(15 , 'Adult Protective Services', 'AS', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(16 , 'Adult Protective Services', 'AS', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(17 , 'Adult Protective Services', 'AS', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(18 , 'Adult Protective Services', 'AS', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(19 , 'Adult Protective Services', 'AS', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(20 , 'Adult Protective Services', 'AS', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(21 , 'Adult Protective Services', 'AS', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(22 , 'Adult Protective Services', 'AS', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(23 , 'Adult Protective Services', 'AS', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(24 , 'Adult Protective Services', 'AS', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(25 , 'Adult Protective Services', 'AS', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(26 , 'Adult Protective Services', 'AS', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(27 , 'CalFresh', 'FS', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(28 , 'CalFresh', 'FS', 'CalFresh - Admin Caused (after 3/2000)', 'AQ')
insert CalSAWSRecoveryAccountCause
values(29 , 'CalFresh', 'FS', 'CalFresh - Admin Caused (prior to 3/2000)', 'AP')
insert CalSAWSRecoveryAccountCause
values(30 , 'CalFresh', 'FS', 'CalFresh - IHE (Customer Caused)', 'AR')
insert CalSAWSRecoveryAccountCause
values(31 , 'CalFresh', 'FS', 'CalFresh - IPV (ADH)', 'AU')
insert CalSAWSRecoveryAccountCause
values(32 , 'CalFresh', 'FS', 'CalFresh - IPV (Court)', 'AV')
insert CalSAWSRecoveryAccountCause
values(33 , 'CalFresh', 'FS', 'CalFresh - IPV (waiver)', 'AT')
insert CalSAWSRecoveryAccountCause
values(34 , 'CalFresh', 'FS', 'CalFresh - Potential IPV', 'AS')
insert CalSAWSRecoveryAccountCause
values(35 , 'CalFresh', 'FS', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(36 , 'CalFresh', 'FS', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(37 , 'CalFresh', 'FS', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(38 , 'Cal-Learn', 'CL', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(39 , 'Cal-Learn', 'CL', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(40 , 'Cal-Learn', 'CL', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(41 , 'Cal-Learn', 'CL', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(42 , 'Cal-Learn', 'CL', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(43 , 'Cal-Learn', 'CL', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(44 , 'Cal-Learn', 'CL', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(45 , 'Cal-Learn', 'CL', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(46 , 'Cal-Learn', 'CL', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(47 , 'Cal-Learn', 'CL', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(48 , 'Cal-Learn', 'CL', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(49 , 'Cal-Learn', 'CL', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(50 , 'Cal-Learn', 'CL', 'Fraud Referral', 'FR')
insert CalSAWSRecoveryAccountCause
values(51 , 'Cal-Learn', 'CL', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(52 , 'CalWORKs', 'CW', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(53 , 'CalWORKs', 'CW', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(54 , 'CalWORKs', 'CW', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(55 , 'CalWORKs', 'CW', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(56 , 'CalWORKs', 'CW', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(57 , 'CalWORKs', 'CW', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(58 , 'CalWORKs', 'CW', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(59 , 'CalWORKs', 'CW', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(60 , 'CalWORKs', 'CW', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(61 , 'CalWORKs', 'CW', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(62 , 'CalWORKs', 'CW', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(63 , 'CalWORKs', 'CW', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(64 , 'CalWORKs', 'CW', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(65 , 'Cash Assistance Program for Immigrants', 'CP', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(66 , 'Cash Assistance Program for Immigrants', 'CP', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(67 , 'Cash Assistance Program for Immigrants', 'CP', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(68 , 'Cash Assistance Program for Immigrants', 'CP', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(69 , 'Cash Assistance Program for Immigrants', 'CP', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(70 , 'Cash Assistance Program for Immigrants', 'CP', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(71 , 'Cash Assistance Program for Immigrants', 'CP', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(72 , 'Cash Assistance Program for Immigrants', 'CP', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(73 , 'Cash Assistance Program for Immigrants', 'CP', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(74 , 'Cash Assistance Program for Immigrants', 'CP', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(75 , 'Cash Assistance Program for Immigrants', 'CP', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(76 , 'Cash Assistance Program for Immigrants', 'CP', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(77 , 'Cash Assistance Program for Immigrants', 'CP', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(78 , 'CalFresh Employment & Training', 'FT', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(79 , 'CalFresh Employment & Training', 'FT', 'CalFresh - Admin Caused (after 3/2000)', 'AQ')
insert CalSAWSRecoveryAccountCause
values(80 , 'CalFresh Employment & Training', 'FT', 'CalFresh - Admin Caused (prior to 3/2000)', 'AP')
insert CalSAWSRecoveryAccountCause
values(81 , 'CalFresh Employment & Training', 'FT', 'CalFresh - IHE (Customer Caused)', 'AR')
insert CalSAWSRecoveryAccountCause
values(82 , 'CalFresh Employment & Training', 'FT', 'CalFresh - IPV (ADH)', 'AU')
insert CalSAWSRecoveryAccountCause
values(83 , 'CalFresh Employment & Training', 'FT', 'CalFresh - IPV (Court)', 'AV')
insert CalSAWSRecoveryAccountCause
values(84 , 'CalFresh Employment & Training', 'FT', 'CalFresh - IPV (waiver)', 'AT')
insert CalSAWSRecoveryAccountCause
values(85 , 'CalFresh Employment & Training', 'FT', 'CalFresh - Potential IPV', 'AS')
insert CalSAWSRecoveryAccountCause
values(86 , 'CalFresh Employment & Training', 'FT', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(87 , 'CalFresh Employment & Training', 'FT', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(88 , 'CalFresh Employment & Training', 'FT', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(89 , 'Child Care', 'CC', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(90 , 'Child Care', 'CC', 'Child Care - Agency Caused (provider responsible)', 'AX')
insert CalSAWSRecoveryAccountCause
values(91 , 'Child Care', 'CC', 'Child Care - Agency Caused (recipient responsible)', 'AW')
insert CalSAWSRecoveryAccountCause
values(92 , 'Child Care', 'CC', 'Child Care - Provider Caused', 'AZ')
insert CalSAWSRecoveryAccountCause
values(93 , 'Child Care', 'CC', 'Child Care - Recipient Caused', 'AY')
insert CalSAWSRecoveryAccountCause
values(94 , 'Child Care', 'CC', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(95 , 'Child Care', 'CC', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(96 , 'Child Care', 'CC', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(97 , 'Child Protective Services', 'CS', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(98 , 'Child Protective Services', 'CS', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(99 , 'Child Protective Services', 'CS', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(100, 'Child Protective Services', 'CS', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(101, 'Child Protective Services', 'CS', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(102, 'Child Protective Services', 'CS', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(103, 'Child Protective Services', 'CS', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(104, 'Child Protective Services', 'CS', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(105, 'Child Protective Services', 'CS', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(106, 'Child Protective Services', 'CS', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(107, 'Child Protective Services', 'CS', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(108, 'Child Protective Services', 'CS', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(109, 'Child Protective Services', 'CS', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(110, 'Disaster CalFresh', 'DC', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(111, 'Disaster CalFresh', 'DC', 'CalFresh - Admin Caused (after 3/2000)', 'AQ')
insert CalSAWSRecoveryAccountCause
values(112, 'Disaster CalFresh', 'DC', 'CalFresh - Admin Caused (prior to 3/2000)', 'AP')
insert CalSAWSRecoveryAccountCause
values(113, 'Disaster CalFresh', 'DC', 'CalFresh - IHE (Customer Caused)', 'AR')
insert CalSAWSRecoveryAccountCause
values(114, 'Disaster CalFresh', 'DC', 'CalFresh - Potential IPV', 'AS')
insert CalSAWSRecoveryAccountCause
values(115, 'Disaster CalFresh', 'DC', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(116, 'Disaster CalFresh', 'DC', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(117, 'Disaster CalFresh', 'DC', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(118, 'Diversion', 'DV', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(119, 'Diversion', 'DV', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(120, 'Diversion', 'DV', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(121, 'Diversion', 'DV', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(122, 'Diversion', 'DV', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(123, 'Diversion', 'DV', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(124, 'Diversion', 'DV', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(125, 'Diversion', 'DV', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(126, 'Diversion', 'DV', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(127, 'Diversion', 'DV', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(128, 'Diversion', 'DV', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(129, 'Diversion', 'DV', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(130, 'Diversion', 'DV', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(131, 'Food Distribution', 'FD', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(132, 'Food Distribution', 'FD', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(133, 'Food Distribution', 'FD', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(134, 'Food Distribution', 'FD', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(135, 'Food Distribution', 'FD', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(136, 'Food Distribution', 'FD', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(137, 'Food Distribution', 'FD', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(138, 'Food Distribution', 'FD', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(139, 'Food Distribution', 'FD', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(140, 'Food Distribution', 'FD', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(141, 'Food Distribution', 'FD', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(142, 'Food Distribution', 'FD', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(143, 'Food Distribution', 'FD', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(144, 'Foster Care', 'FC', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(145, 'Foster Care', 'FC', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(146, 'Foster Care', 'FC', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(147, 'Foster Care', 'FC', 'Foster Care - Admin Caused - ET Responsible', 'BA')
insert CalSAWSRecoveryAccountCause
values(148, 'Foster Care', 'FC', 'Foster Care - Admin Caused - SW Responsible', 'BB')
insert CalSAWSRecoveryAccountCause
values(149, 'Foster Care', 'FC', 'Foster Care - Customer Caused', 'BC')
insert CalSAWSRecoveryAccountCause
values(150, 'Foster Care', 'FC', 'Foster Care - Institution Responsible', 'BD')
insert CalSAWSRecoveryAccountCause
values(151, 'Foster Care', 'FC', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(173, 'GA/GR Automated Solution', 'GR', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(174, 'GA/GR Automated Solution', 'GR', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(175, 'GA/GR Automated Solution', 'GR', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(176, 'GA/GR Automated Solution', 'GR', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(177, 'GA/GR Automated Solution', 'GR', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(178, 'GA/GR Automated Solution', 'GR', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(179, 'GA/GR Automated Solution', 'GR', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(180, 'GA/GR Automated Solution', 'GR', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(181, 'GA/GR Automated Solution', 'GR', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(182, 'GA/GR Employment Services', 'GE', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(183, 'GA/GR Employment Services', 'GE', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(184, 'GA/GR Employment Services', 'GE', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(185, 'GA/GR Employment Services', 'GE', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(186, 'GA/GR Employment Services', 'GE', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(187, 'GA/GR Employment Services', 'GE', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(206, 'GA/GR Immediate Need', 'GI', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(207, 'GA/GR Immediate Need', 'GI', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(208, 'GA/GR Immediate Need', 'GI', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(209, 'GA/GR Immediate Need', 'GI', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(210, 'GA/GR Immediate Need', 'GI', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(211, 'GA/GR Immediate Need', 'GI', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(212, 'GA/GR Immediate Need', 'GI', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(213, 'GA/GR Immediate Need', 'GI', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(214, 'GA/GR Immediate Need', 'GI', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(215, 'General Relief Opportunities for WORK (GROW)', 'GW', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(216, 'General Relief Opportunities for WORK (GROW)', 'GW', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(217, 'General Relief Opportunities for WORK (GROW)', 'GW', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(218, 'General Relief Opportunities for WORK (GROW)', 'GW', 'GROW Ancillary Clothing/Shoes', 'AC')
insert CalSAWSRecoveryAccountCause
values(219, 'General Relief Opportunities for WORK (GROW)', 'GW', 'GROW-Ancillary Books/Supplies/Fees', 'AB')
insert CalSAWSRecoveryAccountCause
values(220, 'General Relief Opportunities for WORK (GROW)', 'GW', 'GROW-Ancillary Guard Card', 'AG')
insert CalSAWSRecoveryAccountCause
values(221, 'General Relief Opportunities for WORK (GROW)', 'GW', 'GROW-Ancillary Haircut', 'AH')
insert CalSAWSRecoveryAccountCause
values(222, 'General Relief Opportunities for WORK (GROW)', 'GW', 'GROW-Ancillary Shower', 'SH')
insert CalSAWSRecoveryAccountCause
values(223, 'General Relief Opportunities for WORK (GROW)', 'GW', 'GROW-Ancillary Tattoo Removal', 'TR')
insert CalSAWSRecoveryAccountCause
values(224, 'General Relief Opportunities for WORK (GROW)', 'GW', 'GROW-Ancillary Tools', 'TO')
insert CalSAWSRecoveryAccountCause
values(225, 'General Relief Opportunities for WORK (GROW)', 'GW', 'GROW-Ancillary Uniform', 'UF')
insert CalSAWSRecoveryAccountCause
values(226, 'General Relief Opportunities for WORK (GROW)', 'GW', 'GROW-Transportation Bus Pass', 'BP')
insert CalSAWSRecoveryAccountCause
values(227, 'General Relief Opportunities for WORK (GROW)', 'GW', 'GROW-Transportation Bus Token', 'BT')
insert CalSAWSRecoveryAccountCause
values(228, 'General Relief Opportunities for WORK (GROW)', 'GW', 'GROW-Transportation Bus Transfer', 'TT')
insert CalSAWSRecoveryAccountCause
values(229, 'General Relief Opportunities for WORK (GROW)', 'GW', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(230, 'Homeless Assistance - Permanent', 'HP', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(231, 'Homeless Assistance - Permanent', 'HP', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(232, 'Homeless Assistance - Permanent', 'HP', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(233, 'Homeless Assistance - Permanent', 'HP', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(234, 'Homeless Assistance - Permanent', 'HP', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(235, 'Homeless Assistance - Permanent', 'HP', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(236, 'Homeless Assistance - Permanent', 'HP', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(237, 'Homeless Assistance - Permanent', 'HP', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(238, 'Homeless Assistance - Permanent', 'HP', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(239, 'Homeless Assistance - Permanent', 'HP', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(240, 'Homeless Assistance - Permanent', 'HP', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(241, 'Homeless Assistance - Permanent', 'HP', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(242, 'Homeless Assistance - Permanent', 'HP', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(243, 'Homeless Assistance - Temporary', 'HT', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(244, 'Homeless Assistance - Temporary', 'HT', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(245, 'Homeless Assistance - Temporary', 'HT', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(246, 'Homeless Assistance - Temporary', 'HT', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(247, 'Homeless Assistance - Temporary', 'HT', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(248, 'Homeless Assistance - Temporary', 'HT', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(249, 'Homeless Assistance - Temporary', 'HT', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(250, 'Homeless Assistance - Temporary', 'HT', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(251, 'Homeless Assistance - Temporary', 'HT', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(252, 'Homeless Assistance - Temporary', 'HT', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(253, 'Homeless Assistance - Temporary', 'HT', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(254, 'Homeless Assistance - Temporary', 'HT', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(255, 'Homeless Assistance - Temporary', 'HT', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(256, 'In-Home Supportive Services/CMIPS II', 'IH', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(257, 'In-Home Supportive Services/CMIPS II', 'IH', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(258, 'In-Home Supportive Services/CMIPS II', 'IH', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(259, 'In-Home Supportive Services/CMIPS II', 'IH', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(260, 'In-Home Supportive Services/CMIPS II', 'IH', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(261, 'In-Home Supportive Services/CMIPS II', 'IH', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(262, 'In-Home Supportive Services/CMIPS II', 'IH', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(263, 'In-Home Supportive Services/CMIPS II', 'IH', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(264, 'In-Home Supportive Services/CMIPS II', 'IH', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(265, 'In-Home Supportive Services/CMIPS II', 'IH', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(266, 'In-Home Supportive Services/CMIPS II', 'IH', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(267, 'In-Home Supportive Services/CMIPS II', 'IH', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(268, 'In-Home Supportive Services/CMIPS II', 'IH', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(269, 'Immediate Need', 'IN', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(270, 'Immediate Need', 'IN', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(271, 'Immediate Need', 'IN', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(272, 'Immediate Need', 'IN', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(273, 'Immediate Need', 'IN', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(274, 'Immediate Need', 'IN', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(275, 'Immediate Need', 'IN', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(276, 'Immediate Need', 'IN', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(277, 'Immediate Need', 'IN', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(278, 'Immediate Need', 'IN', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(279, 'Immediate Need', 'IN', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(280, 'Immediate Need', 'IN', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(281, 'Immediate Need', 'IN', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(282, 'IV-D Child Support', 'IV', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(283, 'IV-D Child Support', 'IV', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(284, 'IV-D Child Support', 'IV', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(285, 'IV-D Child Support', 'IV', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(286, 'IV-D Child Support', 'IV', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(287, 'IV-D Child Support', 'IV', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(288, 'IV-D Child Support', 'IV', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(289, 'IV-D Child Support', 'IV', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(290, 'IV-D Child Support', 'IV', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(291, 'IV-D Child Support', 'IV', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(292, 'IV-D Child Support', 'IV', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(293, 'IV-D Child Support', 'IV', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(294, 'IV-D Child Support', 'IV', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(295, 'Kin-GAP', 'KG', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(296, 'Kin-GAP', 'KG', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(297, 'Kin-GAP', 'KG', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(298, 'Kin-GAP', 'KG', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(299, 'Kin-GAP', 'KG', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(300, 'Kin-GAP', 'KG', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(301, 'Kin-GAP', 'KG', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(302, 'Kin-GAP', 'KG', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(303, 'Kin-GAP', 'KG', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(304, 'Kin-GAP', 'KG', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(305, 'Kin-GAP', 'KG', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(306, 'Kin-GAP', 'KG', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(307, 'Kin-GAP', 'KG', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(308, 'Linkages Adult Services', 'LS', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(309, 'Linkages Adult Services', 'LS', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(310, 'Linkages Adult Services', 'LS', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(311, 'Linkages Adult Services', 'LS', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(312, 'Linkages Adult Services', 'LS', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(313, 'Linkages Adult Services', 'LS', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(314, 'Linkages Adult Services', 'LS', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(315, 'Linkages Adult Services', 'LS', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(316, 'Linkages Adult Services', 'LS', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(317, 'Linkages Adult Services', 'LS', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(318, 'Linkages Adult Services', 'LS', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(319, 'Linkages Adult Services', 'LS', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(320, 'Linkages Adult Services', 'LS', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(321, 'Medi-Cal', 'MC', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(322, 'Medi-Cal', 'MC', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(323, 'Medi-Cal', 'MC', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(324, 'Medi-Cal', 'MC', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(325, 'Medi-Cal', 'MC', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(326, 'Medi-Cal', 'MC', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(327, 'Medi-Cal', 'MC', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(328, 'Medi-Cal', 'MC', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(329, 'Medi-Cal', 'MC', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(330, 'Medi-Cal', 'MC', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(331, 'Medi-Cal', 'MC', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(332, 'Medi-Cal', 'MC', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(333, 'Medi-Cal', 'MC', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(334, 'Multipurpose Senior Services', 'MS', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(335, 'Multipurpose Senior Services', 'MS', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(336, 'Multipurpose Senior Services', 'MS', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(337, 'Multipurpose Senior Services', 'MS', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(338, 'Multipurpose Senior Services', 'MS', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(339, 'Multipurpose Senior Services', 'MS', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(340, 'Multipurpose Senior Services', 'MS', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(341, 'Multipurpose Senior Services', 'MS', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(342, 'Multipurpose Senior Services', 'MS', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(343, 'Multipurpose Senior Services', 'MS', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(344, 'Multipurpose Senior Services', 'MS', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(345, 'Multipurpose Senior Services', 'MS', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(346, 'Multipurpose Senior Services', 'MS', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(347, 'Nutrition Benefit', 'NB', 'SNB - Admin Caused', 'NA')
insert CalSAWSRecoveryAccountCause
values(348, 'Nutrition Benefit', 'NB', 'SNB - Customer Caused', 'NB')
insert CalSAWSRecoveryAccountCause
values(349, 'Nutrition Benefit', 'NB', 'TNB - Admin Caused', 'NC')
insert CalSAWSRecoveryAccountCause
values(350, 'Nutrition Benefit', 'NB', 'TNB - Customer Caused', 'ND')
insert CalSAWSRecoveryAccountCause
values(351, 'Personal Care Services Program', 'PE', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(352, 'Personal Care Services Program', 'PE', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(353, 'Personal Care Services Program', 'PE', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(354, 'Personal Care Services Program', 'PE', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(355, 'Personal Care Services Program', 'PE', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(356, 'Personal Care Services Program', 'PE', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(357, 'Personal Care Services Program', 'PE', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(358, 'Personal Care Services Program', 'PE', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(359, 'Personal Care Services Program', 'PE', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(360, 'Personal Care Services Program', 'PE', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(361, 'Personal Care Services Program', 'PE', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(362, 'Personal Care Services Program', 'PE', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(363, 'Personal Care Services Program', 'PE', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(364, 'Refugee Cash Assistance', 'RC', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(365, 'Refugee Cash Assistance', 'RC', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(366, 'Refugee Cash Assistance', 'RC', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(367, 'Refugee Cash Assistance', 'RC', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(368, 'Refugee Cash Assistance', 'RC', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(369, 'Refugee Cash Assistance', 'RC', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(370, 'Refugee Cash Assistance', 'RC', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(371, 'Refugee Cash Assistance', 'RC', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(372, 'Refugee Cash Assistance', 'RC', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(373, 'Refugee Cash Assistance', 'RC', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(374, 'Refugee Cash Assistance', 'RC', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(375, 'Refugee Cash Assistance', 'RC', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(376, 'Refugee Cash Assistance', 'RC', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(377, 'Refugee Employment Program', 'RE', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(378, 'Refugee Employment Program', 'RE', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(379, 'Refugee Employment Program', 'RE', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(380, 'Refugee Employment Program', 'RE', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(381, 'Refugee Employment Program', 'RE', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(382, 'Refugee Employment Program', 'RE', 'Fraud Referral', 'FR')
insert CalSAWSRecoveryAccountCause
values(383, 'Refugee Employment Program', 'RE', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(384, 'Refugee Employment Program', 'RE', 'Welfare to Work - Ancillary', 'BE')
insert CalSAWSRecoveryAccountCause
values(385, 'Refugee Employment Program', 'RE', 'Welfare to Work - Education', 'BF')
insert CalSAWSRecoveryAccountCause
values(386, 'Refugee Employment Program', 'RE', 'Welfare to Work - Parking', 'BU')
insert CalSAWSRecoveryAccountCause
values(387, 'Refugee Employment Program', 'RE', 'Welfare to Work - Transportation', 'BG')
insert CalSAWSRecoveryAccountCause
values(388, 'Refugee Employment Program', 'RE', 'Welfare to Work - Vehicle Repairs', 'BH')
insert CalSAWSRecoveryAccountCause
values(389, 'SSI Only', 'SI', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(390, 'SSI Only', 'SI', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(391, 'SSI Only', 'SI', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(392, 'SSI Only', 'SI', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(393, 'SSI Only', 'SI', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(394, 'SSI Only', 'SI', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(395, 'SSI Only', 'SI', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(396, 'SSI Only', 'SI', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(397, 'SSI Only', 'SI', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(398, 'SSI Only', 'SI', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(399, 'SSI Only', 'SI', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(400, 'SSI Only', 'SI', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(401, 'SSI Only', 'SI', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(402, 'SSI/SSP', 'SS', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(403, 'SSI/SSP', 'SS', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(404, 'SSI/SSP', 'SS', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(405, 'SSI/SSP', 'SS', 'Cash - IPV (ADH)', 'AM')
insert CalSAWSRecoveryAccountCause
values(406, 'SSI/SSP', 'SS', 'Cash - IPV (Court)', 'AN')
insert CalSAWSRecoveryAccountCause
values(407, 'SSI/SSP', 'SS', 'Cash - IPV (waiver)', 'AL')
insert CalSAWSRecoveryAccountCause
values(408, 'SSI/SSP', 'SS', 'Cash - Late QR7', 'AO')
insert CalSAWSRecoveryAccountCause
values(409, 'SSI/SSP', 'SS', 'Cash - Late SAR7', 'BM')
insert CalSAWSRecoveryAccountCause
values(410, 'SSI/SSP', 'SS', 'Cash - Late Saws-7', 'AO')
insert CalSAWSRecoveryAccountCause
values(411, 'SSI/SSP', 'SS', 'Cash - Potential IPV', 'AK')
insert CalSAWSRecoveryAccountCause
values(412, 'SSI/SSP', 'SS', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(413, 'SSI/SSP', 'SS', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(414, 'SSI/SSP', 'SS', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(415, 'Welfare to Work', 'WT', 'Bounce Check Charges', 'BL')
insert CalSAWSRecoveryAccountCause
values(416, 'Welfare to Work', 'WT', 'Cash - Admin Caused', 'AI')
insert CalSAWSRecoveryAccountCause
values(417, 'Welfare to Work', 'WT', 'Cash - Customer Caused', 'AJ')
insert CalSAWSRecoveryAccountCause
values(418, 'Welfare to Work', 'WT', 'Collection Fee', 'CF')
insert CalSAWSRecoveryAccountCause
values(419, 'Welfare to Work', 'WT', 'Court Filing Fees', 'BJ')
insert CalSAWSRecoveryAccountCause
values(420, 'Welfare to Work', 'WT', 'Fraud Referral', 'FR')
insert CalSAWSRecoveryAccountCause
values(421, 'Welfare to Work', 'WT', 'Sheriff Service Fees', 'BK')
insert CalSAWSRecoveryAccountCause
values(422, 'Welfare to Work', 'WT', 'Welfare to Work - Ancillary', 'BE')
insert CalSAWSRecoveryAccountCause
values(423, 'Welfare to Work', 'WT', 'Welfare to Work - Education', 'BF')
insert CalSAWSRecoveryAccountCause
values(424, 'Welfare to Work', 'WT', 'Welfare to Work - Parking', 'BU')
insert CalSAWSRecoveryAccountCause
values(425, 'Welfare to Work', 'WT', 'Welfare to Work - Transportation', 'BG')
insert CalSAWSRecoveryAccountCause
values(426, 'Welfare to Work', 'WT', 'Welfare to Work - Vehicle Repairs', 'BH')

go










/*   
     system:        CalSAWS Conversion
     procedure:     CalSAWSRecoveryAccountReason.tab
     written by:    Craig Deane
     date written:  9/3/2020
     database:      welcoll
     function:      Creates the CalSAWSRecoveryAccountReason table that holds all of the CalSAWS Recovery Account Reason codes
     modified by:   
     changes:       
 */

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSRecoveryAccountReason') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSRecoveryAccountReason
              END
Go

CREATE TABLE dbo.CalSAWSRecoveryAccountReason
       (number	integer,
	description	varchar(255),
	calsaws_code	char(2),
	PRIMARY KEY (number)
 )
go

grant select, insert, update, delete on CalSAWSRecoveryAccountReason to public
go

insert CalSAWSRecoveryAccountReason
values(1  , 'Act to Misreprsnt/Withld Fcts', 'AM')
insert CalSAWSRecoveryAccountReason
values(2  , 'Admin Caused', 'AC')
insert CalSAWSRecoveryAccountReason
values(3  , 'Administrative Error', 'AE')
insert CalSAWSRecoveryAccountReason
values(4  , 'Aid Paid Pending - State Hearing', 'AP')
insert CalSAWSRecoveryAccountReason
values(5  , 'Batch Process', 'BP')
insert CalSAWSRecoveryAccountReason
values(6  , 'Birthdate Change', 'BD')
insert CalSAWSRecoveryAccountReason
values(7  , 'Bounce Check Charge', 'BC')
insert CalSAWSRecoveryAccountReason
values(8  , 'Budget Factor Missing', 'BM')
insert CalSAWSRecoveryAccountReason
values(9  , 'Budget/Voucher STP Date Discr', 'VD')
insert CalSAWSRecoveryAccountReason
values(10 , 'Change Clothing', 'CG')
insert CalSAWSRecoveryAccountReason
values(11 , 'Change in Housing Cost - Unreported', 'CH')
insert CalSAWSRecoveryAccountReason
values(12 , 'Change in Living Arrangements/Household Composition', 'CL')
insert CalSAWSRecoveryAccountReason
values(13 , 'Change in Status (SSI)', 'CS')
insert CalSAWSRecoveryAccountReason
values(14 , 'Change Income', 'CI')
insert CalSAWSRecoveryAccountReason
values(15 , 'Child Care', 'CC')
insert CalSAWSRecoveryAccountReason
values(16 , 'Child Care - Child Stopped Attending', 'CA')
insert CalSAWSRecoveryAccountReason
values(17 , 'Child Care - Inaccurate Billing', 'IB')
insert CalSAWSRecoveryAccountReason
values(18 , 'Child Care - Increase / Change in Income', 'I6')
insert CalSAWSRecoveryAccountReason
values(19 , 'Child Care - No County-Approved Activity', 'NC')
insert CalSAWSRecoveryAccountReason
values(20 , 'Child Care - Not an Eligible Provider', 'NA')
insert CalSAWSRecoveryAccountReason
values(21 , 'Child Care - Not Eligible to CalWORKS', 'NE')
insert CalSAWSRecoveryAccountReason
values(22 , 'Child Care - Not in an approved activity', 'NL')
insert CalSAWSRecoveryAccountReason
values(23 , 'Child Care - Over Billing', 'OB')
insert CalSAWSRecoveryAccountReason
values(24 , 'Child Care - Wrong Provider Paid', 'WP')
insert CalSAWSRecoveryAccountReason
values(25 , 'Child Care - Wrong Rate Paid', 'WR')
insert CalSAWSRecoveryAccountReason
values(26 , 'Child Support Collections', 'CD')
insert CalSAWSRecoveryAccountReason
values(27 , 'Child Support Cooperation', 'CP')
insert CalSAWSRecoveryAccountReason
values(28 , 'Clothing B/F Missing', 'CM')
insert CalSAWSRecoveryAccountReason
values(29 , 'Collection Fee', 'CE')
insert CalSAWSRecoveryAccountReason
values(30 , 'Convicted Drug Felon', 'CF')
insert CalSAWSRecoveryAccountReason
values(31 , 'Convicted FS-Trafficking', 'CN')
insert CalSAWSRecoveryAccountReason
values(32 , 'Convicted-Trading FS Cpns', 'TS')
insert CalSAWSRecoveryAccountReason
values(33 , 'Court Fees', 'CT')
insert CalSAWSRecoveryAccountReason
values(34 , 'Court Order', 'CR')
insert CalSAWSRecoveryAccountReason
values(35 , 'Court Ordered Restitution', 'CO')
insert CalSAWSRecoveryAccountReason
values(36 , 'Customer Caused', 'CU')
insert CalSAWSRecoveryAccountReason
values(37 , 'Deceased Child', 'DD')
insert CalSAWSRecoveryAccountReason
values(38 , 'Decreased Special Needs', 'DS')
insert CalSAWSRecoveryAccountReason
values(39 , 'DIB', 'DI')
insert CalSAWSRecoveryAccountReason
values(40 , 'DMV Fees', 'DM')
insert CalSAWSRecoveryAccountReason
values(41 , 'Duplicate CalFresh Received', 'DF')
insert CalSAWSRecoveryAccountReason
values(42 , 'Duplicate Child Support Disregard / Pass On', 'DC')
insert CalSAWSRecoveryAccountReason
values(43 , 'Duplicate Payment,Clothing', 'DT')
insert CalSAWSRecoveryAccountReason
values(44 , 'Duplicate Payment,Placement', 'DL')
insert CalSAWSRecoveryAccountReason
values(45 , 'Duplicate Payments Issued', 'DP')
insert CalSAWSRecoveryAccountReason
values(46 , 'Duplicate Warrants Cashed', 'DW')
insert CalSAWSRecoveryAccountReason
values(47 , 'EBT Error', 'EB')
insert CalSAWSRecoveryAccountReason
values(48 , 'Eligible Person / Child Out of Home', 'EP')
insert CalSAWSRecoveryAccountReason
values(49 , 'Emergency Assistance Foster Care', 'EA')
insert CalSAWSRecoveryAccountReason
values(50 , 'Exceed 48 Mths Time Limit', 'EM')
insert CalSAWSRecoveryAccountReason
values(51 , 'Excess Child Care', 'EC')
insert CalSAWSRecoveryAccountReason
values(52 , 'Excess Homeless Assistance', 'EH')
insert CalSAWSRecoveryAccountReason
values(53 , 'Excess Personal Property  (Good Faith)', 'EO')
insert CalSAWSRecoveryAccountReason
values(54 , 'Excess Personal Property  (Not Good Faith)', 'EN')
insert CalSAWSRecoveryAccountReason
values(55 , 'Excess Real Property  (Good Faith)', 'ER')
insert CalSAWSRecoveryAccountReason
values(56 , 'Excess Real Property  (Not Good Faith)', 'EF')
insert CalSAWSRecoveryAccountReason
values(57 , 'Failed to Provide Receipt', 'RF')
insert CalSAWSRecoveryAccountReason
values(58 , 'Failed to Report - Other Parent in Home', 'FR')
insert CalSAWSRecoveryAccountReason
values(59 , 'Failure to Provide Essential Information', 'FP')
insert CalSAWSRecoveryAccountReason
values(60 , 'Financial Sanction Penalty Not Done Timely', 'FN')
insert CalSAWSRecoveryAccountReason
values(61 , 'Fleeing Felon', 'FF')
insert CalSAWSRecoveryAccountReason
values(62 , 'Foster Care', 'FC')
insert CalSAWSRecoveryAccountReason
values(63 , 'Foster Care Social Security', 'FS')
insert CalSAWSRecoveryAccountReason
values(64 , 'Fraud Benefits Betwn 2K-5K', 'FU')
insert CalSAWSRecoveryAccountReason
values(65 , 'Fraud Benefits Less than 2K', 'FL')
insert CalSAWSRecoveryAccountReason
values(66 , 'Fraud Referral', 'FE')
insert CalSAWSRecoveryAccountReason
values(67 , 'Fraudulent Benefits Over 10K', 'FB')
insert CalSAWSRecoveryAccountReason
values(68 , 'Full Time Employment', 'FT')
insert CalSAWSRecoveryAccountReason
values(69 , 'Gain Child Care', 'GC')
insert CalSAWSRecoveryAccountReason
values(70 , 'General Assistance / General Relief', 'GA')
insert CalSAWSRecoveryAccountReason
values(71 , 'Hearing Decision', 'HD')
insert CalSAWSRecoveryAccountReason
values(72 , 'Homeless Assistance - Permanent Recipient', 'HP')
insert CalSAWSRecoveryAccountReason
values(73 , 'Homeless Assistance - Temporary Applicant', 'HA')
insert CalSAWSRecoveryAccountReason
values(74 , 'Homeless Assistance - Temporary Recipient', 'HR')
insert CalSAWSRecoveryAccountReason
values(75 , 'IEVS - Duplicate Aid PARIS', 'I4')
insert CalSAWSRecoveryAccountReason
values(76 , 'IEVS - New Hire', 'IE')
insert CalSAWSRecoveryAccountReason
values(77 , 'IEVS - Unreported Income BEER', 'I1')
insert CalSAWSRecoveryAccountReason
values(78 , 'IEVS - Unreported Income Other', 'I2')
insert CalSAWSRecoveryAccountReason
values(79 , 'IEVS - Unreported Income PVS', 'I3')
insert CalSAWSRecoveryAccountReason
values(80 , 'IEVS - Unreported Property Asset Match', 'I5')
insert CalSAWSRecoveryAccountReason
values(81 , 'Immediate Need', 'IN')
insert CalSAWSRecoveryAccountReason
values(82 , 'In Home Supportive Services (IHSS)', 'IH')
insert CalSAWSRecoveryAccountReason
values(83 , 'Increased / Changed Earned Income', 'IC')
insert CalSAWSRecoveryAccountReason
values(84 , 'Increased / Changed In-Kind Income', 'II')
insert CalSAWSRecoveryAccountReason
values(85 , 'Increased / Changed Other Income', 'IO')
insert CalSAWSRecoveryAccountReason
values(86 , 'Increased / Changed Stepparent Income', 'IS')
insert CalSAWSRecoveryAccountReason
values(87 , 'Intake Recomp', 'IR')
insert CalSAWSRecoveryAccountReason
values(88 , 'Interim Assistance', 'IA')
insert CalSAWSRecoveryAccountReason
values(89 , 'Invalid,All Plmt B/F Cancelled', 'IP')
insert CalSAWSRecoveryAccountReason
values(90 , 'Levy', 'LY')
insert CalSAWSRecoveryAccountReason
values(91 , 'Lien', 'LI')
insert CalSAWSRecoveryAccountReason
values(92 , 'Lump Sum Income', 'LS')
insert CalSAWSRecoveryAccountReason
values(93 , 'Made False/Misleading Stmts', 'MS')
insert CalSAWSRecoveryAccountReason
values(94 , 'Medical Expense', 'ME')
insert CalSAWSRecoveryAccountReason
values(95 , 'Misapplication of Regs', 'MR')
insert CalSAWSRecoveryAccountReason
values(96 , 'Multiple Aid-Falsified Resid', 'MF')
insert CalSAWSRecoveryAccountReason
values(97 , 'Multiple Aid-Multiple Apps', 'MA')
insert CalSAWSRecoveryAccountReason
values(98 , 'New Income', 'NI')
insert CalSAWSRecoveryAccountReason
values(99 , 'No Deprivation', 'ND')
insert CalSAWSRecoveryAccountReason
values(100, 'No State Residence', 'NR')
insert CalSAWSRecoveryAccountReason
values(101, 'Other', 'OH')
insert CalSAWSRecoveryAccountReason
values(102, 'Out of County', 'OC')
insert CalSAWSRecoveryAccountReason
values(103, 'Overpayment Transferred In', 'OT')
insert CalSAWSRecoveryAccountReason
values(104, 'Parole Violator', 'PV')
insert CalSAWSRecoveryAccountReason
values(105, 'Payment Issued/Computer Error', 'PI')
insert CalSAWSRecoveryAccountReason
values(106, 'Personal Income Tax', 'PT')
insert CalSAWSRecoveryAccountReason
values(107, 'Personal Property', 'PP')
insert CalSAWSRecoveryAccountReason
values(108, 'Placement Amount Change', 'PA')
insert CalSAWSRecoveryAccountReason
values(109, 'Placement Start Date Change', 'PC')
insert CalSAWSRecoveryAccountReason
values(110, 'Placement Stop Date Change', 'PS')
insert CalSAWSRecoveryAccountReason
values(111, 'Plmt Contract Vendor Change', 'CV')
insert CalSAWSRecoveryAccountReason
values(112, 'Probation Violator', 'PB')
insert CalSAWSRecoveryAccountReason
values(113, 'Real Property', 'RE')
insert CalSAWSRecoveryAccountReason
values(114, 'Recipient Did Not Meet Reporting Responsibilities', 'RR')
insert CalSAWSRecoveryAccountReason
values(115, 'Recoverable Aid', 'RA')
insert CalSAWSRecoveryAccountReason
values(116, 'Refugee Cash Assistance', 'RC')
insert CalSAWSRecoveryAccountReason
values(117, 'Refused Potentially Avail Inc', 'RP')
insert CalSAWSRecoveryAccountReason
values(118, 'Relationship', 'RL')
insert CalSAWSRecoveryAccountReason
values(119, 'RISP', 'RI')
insert CalSAWSRecoveryAccountReason
values(120, 'RR Benefits', 'RB')
insert CalSAWSRecoveryAccountReason
values(121, 'School Attendance', 'SL')
insert CalSAWSRecoveryAccountReason
values(122, 'Sheriffs Service Fee', 'SS')
insert CalSAWSRecoveryAccountReason
values(123, 'Special Allowance Change', 'SA')
insert CalSAWSRecoveryAccountReason
values(124, 'Special Circumstances', 'SC')
insert CalSAWSRecoveryAccountReason
values(125, 'Sponsored Alien', 'SP')
insert CalSAWSRecoveryAccountReason
values(126, 'SS Benefits', 'SB')
insert CalSAWSRecoveryAccountReason
values(127, 'SSI Approved', 'SI')
insert CalSAWSRecoveryAccountReason
values(128, 'SSN', 'SN')
insert CalSAWSRecoveryAccountReason
values(129, 'Support from Prsn In Home', 'PH')
insert CalSAWSRecoveryAccountReason
values(130, 'Support from Prsn Outside Home', 'PO')
insert CalSAWSRecoveryAccountReason
values(131, 'TANF State FG', 'TF')
insert CalSAWSRecoveryAccountReason
values(132, 'TANF State U', 'TU')
insert CalSAWSRecoveryAccountReason
values(133, 'Technical Overpayment', 'TO')
insert CalSAWSRecoveryAccountReason
values(134, 'Third Fraudulent Act', 'TA')
insert CalSAWSRecoveryAccountReason
values(135, 'Third Party Loss - Court Order', 'TP')
insert CalSAWSRecoveryAccountReason
values(136, 'Timing Out/Time Limits', 'TL')
insert CalSAWSRecoveryAccountReason
values(137, 'Transportation', 'TR')
insert CalSAWSRecoveryAccountReason
values(138, 'UIB', 'UB')
insert CalSAWSRecoveryAccountReason
values(139, 'Unearned Income & HH Change', 'UI')
insert CalSAWSRecoveryAccountReason
values(140, 'Unreported Child Support', 'UC')
insert CalSAWSRecoveryAccountReason
values(141, 'Unreported Income - IEVS', 'IU')
insert CalSAWSRecoveryAccountReason
values(142, 'Unreported Income - Other', 'UE')
insert CalSAWSRecoveryAccountReason
values(143, 'Utility Expenses', 'UT')
insert CalSAWSRecoveryAccountReason
values(144, 'VA Benefits', 'VA')
insert CalSAWSRecoveryAccountReason
values(145, 'Voluntary Repay  (Abatement)', 'VR')
insert CalSAWSRecoveryAccountReason
values(146, 'Warrant Not Held', 'WN')
insert CalSAWSRecoveryAccountReason
values(147, 'Work Registration', 'WK')
insert CalSAWSRecoveryAccountReason
values(148, 'Worker''s Comp Benefits', 'WB')
insert CalSAWSRecoveryAccountReason
values(149, 'Workfare', 'WO')








/*   
     system:        CalSAWS Conversion
     procedure:     CalSAWSRecoveryAccountStatusCode.tab
     written by:    Craig Deane
     date written:  10/12/2020
     database:      welcoll
     function:      Creates the CalSAWSRecoveryAccountStatus table that holds all of the CalSAWS Recovery Account Statuscodes
     modified by:   
     changes:       
 */

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSRecoveryAccountStatusCode') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSRecoveryAccountStatusCode
              END
Go

CREATE TABLE dbo.CalSAWSRecoveryAccountStatusCode
       (number	integer,
	description	varchar(255),
	calsaws_code	char(2),
	PRIMARY KEY (number)
 )
go

grant select, insert, update, delete on CalSAWSRecoveryAccountStatusCode to public
go

insert CalSAWSRecoveryAccountStatusCode
values(1, 'Suspended', 'SU')
insert CalSAWSRecoveryAccountStatusCode
values(2, 'Transferred Out', 'TO')
insert CalSAWSRecoveryAccountStatusCode
values(3, 'Voided', 'VO')
insert CalSAWSRecoveryAccountStatusCode
values(4, 'Active', 'AC')
insert CalSAWSRecoveryAccountStatusCode
values(5, 'Closed', 'CL')
insert CalSAWSRecoveryAccountStatusCode
values(6, 'Pending', 'PE')
insert CalSAWSRecoveryAccountStatusCode
values(7, 'Uncollectible', 'UF')
insert CalSAWSRecoveryAccountStatusCode
values(8, 'Terminated', 'TE')
insert CalSAWSRecoveryAccountStatusCode
values(9, 'New', 'NE')
insert CalSAWSRecoveryAccountStatusCode
values(10, 'Pending Approval', 'AP')
insert CalSAWSRecoveryAccountStatusCode
values(11, 'Pending Agreement', 'PA')
insert CalSAWSRecoveryAccountStatusCode
values(12, 'Discharged', 'DC')
go


/*   
	system:		CalSAWS Conversion
     	procedure:     	CalSAWSRecoveryAccountStatusMap.tab
     	written by:    	Craig Deane
     	date written:  	10/12/2020
     	database:      	welcoll
     	function:      	Creates the CalSAWSRecoveryAccountStatusMap table used to map VACS Debt Status to the CalSAWS Recovery Account Status codes
     	modified by:   	Craig Deane 6/10/2021 FSD 1.7
     	changes:       	Added the exclude_zero_balance_indicator column 
*/

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSRecoveryAccountStatusMap') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSRecoveryAccountStatusMap
              END
Go

CREATE TABLE dbo.CalSAWSRecoveryAccountStatusMap
       (vacs_code	char(1),
	vacs_description	varchar(255),
	calsaws_description	varchar(255),
	calsaws_code	char(2),
	exclude_zero_balance_indicator	char(1) default 0
	Primary Key(vacs_code)
 )
go

grant select, insert, update, delete on CalSAWSRecoveryAccountStatusMap to public
go

insert CalSAWSRecoveryAccountStatusMap
values('A', 'Cancel', 'Voided', 'VO', 0)
insert CalSAWSRecoveryAccountStatusMap
values('B', 'Bankruptcy', 'Suspended', 'SU', 0)
insert CalSAWSRecoveryAccountStatusMap
values('C', 'Closed', 'Closed', 'CL', 0)
insert CalSAWSRecoveryAccountStatusMap
values('D', 'Deceased', 'Terminated', 'TE', 0)
insert CalSAWSRecoveryAccountStatusMap
values('H', 'Hearing', 'Suspended', 'SU', 0)
insert CalSAWSRecoveryAccountStatusMap
values('L', 'Lomeli Write Off', 'Terminated', 'TE', 0)
insert CalSAWSRecoveryAccountStatusMap
values('O', 'Open', 'Active', 'AC', 0)
insert CalSAWSRecoveryAccountStatusMap
values('P', 'Pending', 'Pending', 'PE', 0)
insert CalSAWSRecoveryAccountStatusMap
values('S', 'Suspend', 'Suspended', 'SU', 0)
insert CalSAWSRecoveryAccountStatusMap
values('V', 'Void', 'Voided', 'VO', 0)
insert CalSAWSRecoveryAccountStatusMap
values('W', 'Write Off', 'Terminated', 'TE', 0)

go





/*   
     system:        CalSAWS Conversion
     procedure:     CalSAWSRecoveryAccountStatusReason.tab
     written by:    Craig Deane
     date written:  4/29/2021
     database:      welcoll
     function:      Creates the CalSAWSRecoveryAccountStatusReason table that holds all of the CalSAWS Recovery Account Status Reason codes
     modified by:   
     changes:       
 */

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSRecoveryAccountStatusReason') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSRecoveryAccountStatusReason
              END
Go

CREATE TABLE dbo.CalSAWSRecoveryAccountStatusReason
       (number	integer,
	description	varchar(255),
	calsaws_code	char(2),
	PRIMARY KEY (number)
 )
go

grant select, insert, update, delete on CalSAWSRecoveryAccountStatusReason to public
go

insert CalSAWSRecoveryAccountStatusReason
values(1, 'Active', 'AC')
insert CalSAWSRecoveryAccountStatusReason
values(2, 'Admin Decision', 'AD')
insert CalSAWSRecoveryAccountStatusReason
values(3, 'Admin Error', 'AE')
insert CalSAWSRecoveryAccountStatusReason
values(4, 'Admin Hearing', 'AH')
insert CalSAWSRecoveryAccountStatusReason
values(5, 'Bankruptcy', 'BR')
insert CalSAWSRecoveryAccountStatusReason
values(6, 'Bass v. Anderson', 'BA')
insert CalSAWSRecoveryAccountStatusReason
values(7, 'CF - $125 or Less Admin Error', 'FS')
insert CalSAWSRecoveryAccountStatusReason
values(8, 'CF - $35 or Less Admin Error', 'FT')
insert CalSAWSRecoveryAccountStatusReason
values(9, 'Collection Agency', 'CA')
insert CalSAWSRecoveryAccountStatusReason
values(10, 'Community Service', 'CS')
insert CalSAWSRecoveryAccountStatusReason
values(11, 'Compromised (Lomeli)', 'CL')
insert CalSAWSRecoveryAccountStatusReason
values(12, 'Cost', 'CO')
insert CalSAWSRecoveryAccountStatusReason
values(13, 'Deceased', 'DE')
insert CalSAWSRecoveryAccountStatusReason
values(14, 'Do Not Collect', 'FC')
insert CalSAWSRecoveryAccountStatusReason
values(15, 'Expired Statute', 'ES')
insert CalSAWSRecoveryAccountStatusReason
values(16, 'In-Process', 'IP')
insert CalSAWSRecoveryAccountStatusReason
values(17, 'Nutrition Benefit - Do not collect', 'NB')
insert CalSAWSRecoveryAccountStatusReason
values(18, 'Paid in Full', 'PF')
insert CalSAWSRecoveryAccountStatusReason
values(19, 'Pending Authorization', 'PA')
insert CalSAWSRecoveryAccountStatusReason
values(20, 'Pending Bankruptcy', 'PB')
insert CalSAWSRecoveryAccountStatusReason
values(21, 'Pending Fraud Prosecution', 'PP')
insert CalSAWSRecoveryAccountStatusReason
values(22, 'Policy Threshold Limit', 'PT')
insert CalSAWSRecoveryAccountStatusReason
values(23, 'Prison', 'PR')
insert CalSAWSRecoveryAccountStatusReason
values(24, 'Returned Warrant', 'RW')
insert CalSAWSRecoveryAccountStatusReason
values(25, 'Social Security', 'SS')
insert CalSAWSRecoveryAccountStatusReason
values(26, 'Tax Intercept', 'TI')
insert CalSAWSRecoveryAccountStatusReason
values(27, 'Transferred Out', 'TO')
insert CalSAWSRecoveryAccountStatusReason
values(28, 'Unable to Locate', 'UL')
insert CalSAWSRecoveryAccountStatusReason
values(29, 'Write-Off', 'WO')

go


/*   
	system:		CalSAWS Conversion
     	procedure:     	CalSAWSSettings.tab
     	written by:    	Craig Deane
     	date written:  	2/9/2021
     	database:      	welcoll
     	function:      	Creates the Settings table
     	modified by:   	Craig Deane 3/10/2021
     	changes:       	Added the other_reason_text_ind column for the zero balance debt criterion	
     	modified by:   	Craig Deane 6/10/2021 FSD 1.7
     	changes:	Added the exclude_non_bic_ind, transaction_date_ind, county_code, and cutoff_date_field_ind columns
     	modified by:   	Craig Deane 7/28/2021 FSD 1.8
     	changes: 	Added the show_all_mappings and show_all_cleanup_records columns	  
     	modified by:   	Craig Deane 1/11/2022 Version 2.1
     	changes:    	Added the golive_date column
     	modified by:   	Craig Deane 4/5/2022 Version 2.2
     	changes: 	Added the notification_date_use and notification_date_offset columns
     	modified by:   	Craig Deane  Version 2.3
     	changes: 	Added the case_notes_length column
     	modified by:   	Craig Deane  Version 2.5.1
     	changes: 	Added the delete_special_chars_file7 and alerts_file7 columns

 */

use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSSettings') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSSettings
              END
Go

CREATE TABLE dbo.CalSAWSSettings
(
	key_value		integer,
	data_set_percentage  	integer,
	date_cutoff_years	integer,
	date_cutoff_months	integer,
	date_cutoff_days	integer,
	other_reason_text_ind	char(1),
	staff_id_ind		integer,
	extract_path		varchar(255),
	exclude_non_bic_ind	char(1),
	transaction_date_ind	int,
	county_code		char(2),
	cutoff_date_field_ind	integer,
	show_all_mappings 		integer,
	show_all_cleanup_records	integer,
	golive_date		datetime,
	notification_date_use	int,
	notification_date_offset	int,
	case_notes_length	int,
	delete_special_chars_file7	char(1),
	alerts_file7			char(1)


	PRIMARY KEY(key_value) 
)
go

grant select, insert, update, delete on CalSAWSSettings to public
go


insert CalSAWSSettings
values(1, 100, 3, 0, 0, 'N', 0, '', 'N', 0, '', 0, 1, 1, null, 0, 0, 2000, 'N', 'N')
go

/*   
     	system:		CalSAWS Conversion
     	procedure:     	CalSAWSTransactionType.tab
     	written by:    	Craig Deane
     	date written:  	10/14/2020
     	database:      	welcoll
     	function:      	Creates the CalSAWSTransactionType table that holds all of the CalSAWS Transaction Types
     	modified by:   	Craig Deane 9/30/2021 Version 2.0
	changes:       	Modified data from CalSAWS
*/
use welcoll
go
 

IF OBJECT_ID('dbo.CalSAWSTransactionType') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.CalSAWSTransactionType
              END
Go

CREATE TABLE dbo.CalSAWSTransactionType
       (number	integer,
	description	varchar(255),
	calsaws_code	char(3),
	PRIMARY KEY (number)
 )
go

grant select, insert, update, delete on CalSAWSTransactionType to public
go

insert CalSAWSTransactionType
values(1  , 'AP- USCB OCA', 'US ')
insert CalSAWSTransactionType
values(2  , 'AP-Linebarger OCA', 'LB ')
insert CalSAWSTransactionType
values(3  , 'Advance Refund', 'AV ')
insert CalSAWSTransactionType
values(4  , 'Back Out', 'BO ')
insert CalSAWSTransactionType
values(5  , 'Bad Check', 'BC ')
insert CalSAWSTransactionType
values(6  , 'Benefit Reduction', 'BR ')
insert CalSAWSTransactionType
values(7  , 'CalFresh Coupons', 'FS ')
insert CalSAWSTransactionType
values(8  , 'Cash', 'CH ')
insert CalSAWSTransactionType
values(9  , 'Check', 'CK ')
insert CalSAWSTransactionType
values(10 , 'Child Support Collection', 'CI ')
insert CalSAWSTransactionType
values(11 , 'Claims Against Other Benefits/Settlements', 'BS ')
insert CalSAWSTransactionType
values(12 , 'Collection Fee - DPSS', 'CD ')
insert CalSAWSTransactionType
values(13 , 'Collection Fee - Treasure Tax Collector', 'CT ')
insert CalSAWSTransactionType
values(14 , 'Compromised', 'CO ')
insert CalSAWSTransactionType
values(15 , 'Courtesy Adjustment from Another County', 'CC ')
insert CalSAWSTransactionType
values(16 , 'Credit Card', 'CR ')
insert CalSAWSTransactionType
values(17 , 'Credit Card/Debit Card', 'DB ')
insert CalSAWSTransactionType
values(18 , 'Dedicated Amount', 'DA ')
insert CalSAWSTransactionType
values(19 , 'Dual County Payment', 'DC ')
insert CalSAWSTransactionType
values(20 , 'EBT - CalFresh', 'EF ')
insert CalSAWSTransactionType
values(21 , 'EBT - Cash', 'EC ')
insert CalSAWSTransactionType
values(22 , 'Earned Interest', 'EI ')
insert CalSAWSTransactionType
values(23 , 'Electronic Check', 'EL ')
insert CalSAWSTransactionType
values(24 , 'Equitable Estoppel', 'EE ')
insert CalSAWSTransactionType
values(25 , 'Expungement', 'EX ')
insert CalSAWSTransactionType
values(26 , 'External Refund', 'AR ')
insert CalSAWSTransactionType
values(27 , 'F/C Abatement', 'FC ')
insert CalSAWSTransactionType
values(28 , 'F/C Payment', 'FP ')
insert CalSAWSTransactionType
values(29 , 'F/C SSA', 'FA ')
insert CalSAWSTransactionType
values(30 , 'F/C SSI', 'FI ')
insert CalSAWSTransactionType
values(31 , 'F/C UIB', 'FU ')
insert CalSAWSTransactionType
values(32 , 'F/C VA Benefits Reduction', 'FV ')
insert CalSAWSTransactionType
values(33 , 'F/C Workmans Comp', 'FW ')
insert CalSAWSTransactionType
values(34 , 'ICT In from another County', 'II ')
insert CalSAWSTransactionType
values(35 , 'ICT Out to new County', 'IO ')
insert CalSAWSTransactionType
values(36 , 'Installment Payments', 'IP ')
insert CalSAWSTransactionType
values(37 , 'Judgement', 'JD ')
insert CalSAWSTransactionType
values(38 , 'Levy Payment', 'LP ')
insert CalSAWSTransactionType
values(39 , 'Lien', 'LE ')
insert CalSAWSTransactionType
values(40 , 'Lost Adjustment', 'LA ')
insert CalSAWSTransactionType
values(41 , 'Money Order', 'MO ')
insert CalSAWSTransactionType
values(42 , 'Offset', 'OF ')
insert CalSAWSTransactionType
values(43 , 'Offset Payment', 'OP ')
insert CalSAWSTransactionType
values(44 , 'Other Agency Collection', 'OA ')
insert CalSAWSTransactionType
values(45 , 'Other Agency Collection - DPSS', 'OD ')
insert CalSAWSTransactionType
values(46 , 'Other Agency Collection - Treasure Tax Collector', 'OT ')
insert CalSAWSTransactionType
values(47 , 'Overpayment Adjustment Transaction', 'OV ')
insert CalSAWSTransactionType
values(48 , 'PayPal', 'PP ')
insert CalSAWSTransactionType
values(49 , 'Payment Reduction', 'PR ')
insert CalSAWSTransactionType
values(50 , 'Period of Ineligibility Recoupment', 'PO ')
insert CalSAWSTransactionType
values(51 , 'Prior Collection', 'PL ')
insert CalSAWSTransactionType
values(52 , 'Prior Conversion', 'PC ')
insert CalSAWSTransactionType
values(53 , 'Recoveries of Aid-SSI', 'RA ')
insert CalSAWSTransactionType
values(54 , 'Refund', 'RF ')
insert CalSAWSTransactionType
values(55 , 'Refund Reversal', 'RS ')
insert CalSAWSTransactionType
values(56 , 'Reimbursement of Aid', 'RI ')
insert CalSAWSTransactionType
values(57 , 'Returned Warrant', 'RW ')
insert CalSAWSTransactionType
values(58 , 'Revenue & Reimbursement Collection', 'RP ')
insert CalSAWSTransactionType
values(59 , 'Revenue & Reimbursement Refund', 'RR ')
insert CalSAWSTransactionType
values(60 , 'SSA Offset Adjustment', 'AA ')
insert CalSAWSTransactionType
values(61 , 'SSA Payment', 'SA ')
insert CalSAWSTransactionType
values(62 , 'SSI Offset Adjustment', 'IA ')
insert CalSAWSTransactionType
values(63 , 'SSI Payment', 'SP ')
insert CalSAWSTransactionType
values(64 , 'Spend Down', 'SD ')
insert CalSAWSTransactionType
values(65 , 'TTC 545 - IRS (17.5%)', 'T17')
insert CalSAWSTransactionType
values(66 , 'TTC 547 - IRS (82.5%)', 'T82')
insert CalSAWSTransactionType
values(67 , 'Tax Intercept - FTB (65%)', 'FT ')
insert CalSAWSTransactionType
values(68 , 'Tax Intercept - FTB (CalFresh)', 'TF ')
insert CalSAWSTransactionType
values(69 , 'Tax Intercept - FTB (cash)', 'TC ')
insert CalSAWSTransactionType
values(70 , 'Tax Intercept - IRS (35%)', 'TI ')
insert CalSAWSTransactionType
values(71 , 'Tax Intercept - IRS (65%)', 'TR ')
insert CalSAWSTransactionType
values(72 , 'Tax Intercept - Process Refund', 'TS ')
insert CalSAWSTransactionType
values(73 , 'Tax Intercept Reversal', 'TV ')
insert CalSAWSTransactionType
values(74 , 'Terminated', 'TE ')
insert CalSAWSTransactionType
values(75 , 'Transfer', 'TN ')
insert CalSAWSTransactionType
values(76 , 'Transfer to General Fund', 'TG ')
insert CalSAWSTransactionType
values(77 , 'Void', 'VO ')
insert CalSAWSTransactionType
values(78 , 'Wage Garnishment', 'WG ')
insert CalSAWSTransactionType
values(79 , 'Written Off', 'WO ')







/*   
     system:        CalSAWS Conversion
     procedure:     DebtList.tab
     written by:    Craig Deane
     date written:  2/3/2021
     database:      welcoll
     function:      Creates the DebtList table. This holds the debt numbers that will be used after filtering
     modified by:   Craig Deane 1/11/2022 Version 2.1
     changes:       Added the file8_process_indicator to differentiate debts
   
 */

use welcoll
go
 

IF OBJECT_ID('dbo.DebtList') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.DebtList
              END
Go

CREATE TABLE dbo.DebtList
(
	debt_number		integer,
	file8_process_indicator char(1)
	PRIMARY KEY (debt_number)
)
go

grant select, insert, update, delete on DebtList to public
go



/*   
     system:        CalSAWS Conversion
     procedure:     PriorityNumber.tab
     written by:    Craig Deane
     date written:  10/7/2020
     database:      welcoll
     function:      Creates the PriorityNumber table
     modified by:   
     changes:       
   
 */

use welcoll
go
 

IF OBJECT_ID('dbo.PriorityNumber') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.PriorityNumber
              END
Go

CREATE TABLE dbo.PriorityNumber
(
	priority_number		integer,
	serial_number		char(9),
	debt_number		integer	
)
go

grant select, insert, update, delete on PriorityNumber to public
go



/*   
     system:        CalSAWS Conversion
     procedure:     VACSWorkers.tab
     written by:    Craig Deane
     date written:  7/19/2021
     date released: 7/28/2021
     database:      welcoll
     function:      Creates the VACSWorkers table
     modified by:   Craig Deane Version 10/21/2021 Version 2.0.1
     changes:       Changed the primary key to only include the first column
 */

use welcoll
go
 

IF OBJECT_ID('dbo.VACSWorkers') IS NOT NULL
              BEGIN
                      DROP TABLE dbo.VACSWorkers
              END
Go

CREATE TABLE dbo.VACSWorkers
(
	VACSWorker		 char(4) Not Null,
	CalWINUserID		varchar(15)

	PRIMARY KEY(VACSWorker) 
)
go

grant select, insert, update, delete on VACSWorkers to public
go




